package cn.dg32z.lon.utils.nmsutil;

import cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion;
import cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.Direction;
import cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.WrappedBlockState;
import cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.type.StateType;
import cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.type.StateTypes;
import cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d;
import cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3i;
import cn.dg32z.lon.player.PlayerData;
import cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox;
import cn.dg32z.lon.utils.data.tag.SyncedTags;
import com.google.common.collect.ImmutableList;
import java.security.MessageDigest;
import java.util.List;
import javax.crypto.Cipher;
import javax.crypto.SecretKeyFactory;
import javax.crypto.spec.DESKeySpec;
import javax.crypto.spec.IvParameterSpec;
import org.bukkit.util.Vector;

/* loaded from: cn_dg32z_lon_utils_nmsutil.jar:cn/dg32z/lon/utils/nmsutil/Collisions.class */
public final class Collisions {
    private static final List nonStupidityCombinations;
    private static final List allAxisCombinations;
    public static final ImmutableList YXZ_AXIS_ORDER;
    private static final double COLLISION_EPSILON;
    public static final ImmutableList YZX_AXIS_ORDER;

    /* JADX WARN: Failed to restore enum class, 'enum' modifier and super class removed */
    /* loaded from: cn_dg32z_lon_utils_nmsutil.jar:cn/dg32z/lon/utils/nmsutil/Collisions$Axis.class */
    public abstract class Axis {
        public static final Axis Z;
        private static final /* synthetic */ Axis[] $VALUES;
        public static final Axis Y;
        public static final Axis X;
        static Object a;

        /* JADX WARN: Multi-variable type inference failed */
        static {
            int i;
            byte[] bytes = "A7íù~Cºùv§{¦\u001da\u0081{}øß·¹\u009cs8{ôÙ9Ë¯Yö«Z\rì\u0098¿´O\u00adÖ\u008a±\u0007ïú©".getBytes("ISO_8859_1");
            byte[] bytes2 = "\u000e\u0091ÍÏP)¸Ö".getBytes("ISO_8859_1");
            int i2 = 0;
            int length = bytes.length;
            do {
                switch (bytes[i2] & 255) {
                    case false:
                        i = 1239360587;
                        break;
                    case true:
                        i = 1209494623;
                        break;
                    case true:
                        i = 1203992245;
                        break;
                    case true:
                        i = 370634568;
                        break;
                    case true:
                        i = 1064006617;
                        break;
                    case true:
                        i = -485885640;
                        break;
                    case true:
                        i = -236774872;
                        break;
                    case true:
                        i = 887430773;
                        break;
                    case true:
                        i = -1261663674;
                        break;
                    case true:
                        i = 1629257693;
                        break;
                    case true:
                        i = 337485004;
                        break;
                    case true:
                        i = 698195956;
                        break;
                    case true:
                        i = -599334710;
                        break;
                    case true:
                        i = -2017930709;
                        break;
                    case true:
                        i = -1745227703;
                        break;
                    case true:
                        i = 1299307176;
                        break;
                    case true:
                        i = -318559751;
                        break;
                    case true:
                        i = 1918092802;
                        break;
                    case true:
                        i = -2108443075;
                        break;
                    case true:
                        i = -361235661;
                        break;
                    case true:
                        i = 2108863393;
                        break;
                    case true:
                        i = -668100995;
                        break;
                    case true:
                        i = 703806813;
                        break;
                    case true:
                        i = 1801292732;
                        break;
                    case true:
                        i = 1922631091;
                        break;
                    case true:
                        i = -316974514;
                        break;
                    case true:
                        i = 790271058;
                        break;
                    case true:
                        i = -203974162;
                        break;
                    case true:
                        i = -1167566533;
                        break;
                    case true:
                        i = -597670026;
                        break;
                    case true:
                        i = 1550311189;
                        break;
                    case true:
                        i = -1075457843;
                        break;
                    case true:
                        i = -1407916162;
                        break;
                    case true:
                        i = -977871665;
                        break;
                    case true:
                        i = -2001894747;
                        break;
                    case true:
                        i = 1071168993;
                        break;
                    case true:
                        i = 2073890637;
                        break;
                    case true:
                        i = -32027045;
                        break;
                    case true:
                        i = 1281679785;
                        break;
                    case true:
                        i = 1499117518;
                        break;
                    case true:
                        i = 453171940;
                        break;
                    case true:
                        i = 1355399654;
                        break;
                    case true:
                        i = 1550365568;
                        break;
                    case true:
                        i = 901648624;
                        break;
                    case true:
                        i = -912955804;
                        break;
                    case true:
                        i = 522727084;
                        break;
                    case true:
                        i = 1525692357;
                        break;
                    case true:
                        i = 986356044;
                        break;
                    case true:
                        i = 1148137303;
                        break;
                    case true:
                        i = -1621297908;
                        break;
                    case true:
                        i = 798277920;
                        break;
                    case true:
                        i = 275749764;
                        break;
                    case true:
                        i = -638038430;
                        break;
                    case true:
                        i = -1985443005;
                        break;
                    case true:
                        i = 2076146394;
                        break;
                    case true:
                        i = 979288194;
                        break;
                    case true:
                        i = -846587970;
                        break;
                    case true:
                        i = 1099547375;
                        break;
                    case true:
                        i = -1837812256;
                        break;
                    case true:
                        i = -739794937;
                        break;
                    case true:
                        i = 1648606445;
                        break;
                    case true:
                        i = -909540591;
                        break;
                    case true:
                        i = -984432275;
                        break;
                    case true:
                        i = 1572005201;
                        break;
                    case true:
                        i = 1391841109;
                        break;
                    case true:
                        i = -2128340961;
                        break;
                    case true:
                        i = -1393810066;
                        break;
                    case true:
                        i = 1937193622;
                        break;
                    case true:
                        i = 1527044041;
                        break;
                    case true:
                        i = -27832482;
                        break;
                    case true:
                        i = -454719347;
                        break;
                    case true:
                        i = 1253145282;
                        break;
                    case true:
                        i = 260133206;
                        break;
                    case true:
                        i = 922620630;
                        break;
                    case true:
                        i = 474276571;
                        break;
                    case true:
                        i = 1577898133;
                        break;
                    case true:
                        i = -1833583681;
                        break;
                    case true:
                        i = 303513519;
                        break;
                    case true:
                        i = 887594119;
                        break;
                    case true:
                        i = -356597091;
                        break;
                    case true:
                        i = 2102502521;
                        break;
                    case true:
                        i = 1453252003;
                        break;
                    case true:
                        i = -638077636;
                        break;
                    case true:
                        i = 1625707780;
                        break;
                    case true:
                        i = -1453144249;
                        break;
                    case true:
                        i = -1652687263;
                        break;
                    case true:
                        i = -1729091271;
                        break;
                    case true:
                        i = -1925398506;
                        break;
                    case true:
                        i = -1162104782;
                        break;
                    case true:
                        i = 763814252;
                        break;
                    case true:
                        i = 1266198412;
                        break;
                    case true:
                        i = -1269210671;
                        break;
                    case true:
                        i = 1350139540;
                        break;
                    case true:
                        i = -445110040;
                        break;
                    case true:
                        i = -295909115;
                        break;
                    case true:
                        i = -1380848332;
                        break;
                    case true:
                        i = -1571771989;
                        break;
                    case true:
                        i = 475742122;
                        break;
                    case true:
                        i = -882678920;
                        break;
                    case true:
                        i = 295373794;
                        break;
                    case true:
                        i = -194839819;
                        break;
                    case true:
                        i = -1992346687;
                        break;
                    case true:
                        i = -720459770;
                        break;
                    case true:
                        i = 18662947;
                        break;
                    case true:
                        i = 870254256;
                        break;
                    case true:
                        i = 1100129837;
                        break;
                    case true:
                        i = -191488143;
                        break;
                    case true:
                        i = -474898150;
                        break;
                    case true:
                        i = 1204545556;
                        break;
                    case true:
                        i = -160128278;
                        break;
                    case true:
                        i = -805847724;
                        break;
                    case true:
                        i = -1791089480;
                        break;
                    case true:
                        i = 577374687;
                        break;
                    case true:
                        i = 645753284;
                        break;
                    case true:
                        i = -1207068293;
                        break;
                    case true:
                        i = 16395250;
                        break;
                    case true:
                        i = -2101600301;
                        break;
                    case true:
                        i = -1476555031;
                        break;
                    case true:
                        i = 1097468549;
                        break;
                    case true:
                        i = -1679530400;
                        break;
                    case true:
                        i = 425318683;
                        break;
                    case true:
                        i = 12776472;
                        break;
                    case true:
                        i = -829151971;
                        break;
                    case true:
                        i = -571754137;
                        break;
                    case true:
                        i = -1981826793;
                        break;
                    case true:
                        i = -1990689709;
                        break;
                    case true:
                        i = -1822756297;
                        break;
                    case true:
                        i = -209620558;
                        break;
                    case true:
                        i = -1855575734;
                        break;
                    case true:
                        i = -2085714112;
                        break;
                    case true:
                        i = 1737869489;
                        break;
                    case true:
                        i = -721253776;
                        break;
                    case true:
                        i = -1666987742;
                        break;
                    case true:
                        i = -1788378023;
                        break;
                    case true:
                        i = -267607828;
                        break;
                    case true:
                        i = -1651150270;
                        break;
                    case true:
                        i = -604146364;
                        break;
                    case true:
                        i = -1914354388;
                        break;
                    case true:
                        i = 246113537;
                        break;
                    case true:
                        i = -218301295;
                        break;
                    case true:
                        i = -1693935216;
                        break;
                    case true:
                        i = -320289169;
                        break;
                    case true:
                        i = 1271887838;
                        break;
                    case true:
                        i = 448298866;
                        break;
                    case true:
                        i = 1646969352;
                        break;
                    case true:
                        i = 962565880;
                        break;
                    case true:
                        i = -1582368277;
                        break;
                    case true:
                        i = -1311486009;
                        break;
                    case true:
                        i = 1850440743;
                        break;
                    case true:
                        i = 773271744;
                        break;
                    case true:
                        i = 617454222;
                        break;
                    case true:
                        i = 323813747;
                        break;
                    case true:
                        i = -230949249;
                        break;
                    case true:
                        i = -188756188;
                        break;
                    case true:
                        i = -647304549;
                        break;
                    case true:
                        i = 807090592;
                        break;
                    case true:
                        i = -1580585734;
                        break;
                    case true:
                        i = -869427163;
                        break;
                    case true:
                        i = 1242726236;
                        break;
                    case true:
                        i = -886773092;
                        break;
                    case true:
                        i = 1571481116;
                        break;
                    case true:
                        i = 1449145600;
                        break;
                    case true:
                        i = 1463181441;
                        break;
                    case true:
                        i = -1112783562;
                        break;
                    case true:
                        i = -1010713311;
                        break;
                    case true:
                        i = -2100944598;
                        break;
                    case true:
                        i = 792761015;
                        break;
                    case true:
                        i = -1650211465;
                        break;
                    case true:
                        i = -1760920189;
                        break;
                    case true:
                        i = 1253199289;
                        break;
                    case true:
                        i = 1645261558;
                        break;
                    case true:
                        i = 164760368;
                        break;
                    case true:
                        i = -1211425267;
                        break;
                    case true:
                        i = -967840261;
                        break;
                    case true:
                        i = -827920535;
                        break;
                    case true:
                        i = 656903124;
                        break;
                    case true:
                        i = -168093616;
                        break;
                    case true:
                        i = 415856359;
                        break;
                    case true:
                        i = 2114840079;
                        break;
                    case true:
                        i = -632083574;
                        break;
                    case true:
                        i = -1086904807;
                        break;
                    case true:
                        i = 1075129560;
                        break;
                    case true:
                        i = -542564546;
                        break;
                    case true:
                        i = -809348123;
                        break;
                    case true:
                        i = 1164374597;
                        break;
                    case true:
                        i = 2032851103;
                        break;
                    case true:
                        i = -786024360;
                        break;
                    case true:
                        i = -166975864;
                        break;
                    case true:
                        i = -1649657683;
                        break;
                    case true:
                        i = -108303765;
                        break;
                    case true:
                        i = 866841374;
                        break;
                    case true:
                        i = 579783307;
                        break;
                    case true:
                        i = -964077313;
                        break;
                    case true:
                        i = -1539528695;
                        break;
                    case true:
                        i = -658850519;
                        break;
                    case true:
                        i = -654245721;
                        break;
                    case true:
                        i = -358125298;
                        break;
                    case true:
                        i = -672646220;
                        break;
                    case true:
                        i = 1609721194;
                        break;
                    case true:
                        i = -1138131802;
                        break;
                    case true:
                        i = 1635934973;
                        break;
                    case true:
                        i = -823218379;
                        break;
                    case true:
                        i = 1264650916;
                        break;
                    case true:
                        i = -619663920;
                        break;
                    case true:
                        i = 1388538627;
                        break;
                    case true:
                        i = 1848914379;
                        break;
                    case true:
                        i = 1999735765;
                        break;
                    case true:
                        i = -1575423901;
                        break;
                    case true:
                        i = -763807826;
                        break;
                    case true:
                        i = 91631251;
                        break;
                    case true:
                        i = 583529018;
                        break;
                    case true:
                        i = -1380689626;
                        break;
                    case true:
                        i = 1172736831;
                        break;
                    case true:
                        i = -111796582;
                        break;
                    case true:
                        i = 2041225969;
                        break;
                    case true:
                        i = -2077322486;
                        break;
                    case true:
                        i = -1064375646;
                        break;
                    case true:
                        i = -1254683802;
                        break;
                    case true:
                        i = -1312336698;
                        break;
                    case true:
                        i = 2020899377;
                        break;
                    case true:
                        i = 1371202438;
                        break;
                    case true:
                        i = -1898925452;
                        break;
                    case true:
                        i = 1327503951;
                        break;
                    case true:
                        i = -1070959645;
                        break;
                    case true:
                        i = 1378082968;
                        break;
                    case true:
                        i = -2144055918;
                        break;
                    case true:
                        i = 1525478923;
                        break;
                    case true:
                        i = 1727901626;
                        break;
                    case true:
                        i = 840016777;
                        break;
                    case true:
                        i = 606886501;
                        break;
                    case true:
                        i = -1845312837;
                        break;
                    case true:
                        i = -13908120;
                        break;
                    case true:
                        i = 3263322;
                        break;
                    case true:
                        i = 631369596;
                        break;
                    case true:
                        i = -199724106;
                        break;
                    case true:
                        i = 788493946;
                        break;
                    case true:
                        i = 1930696668;
                        break;
                    case true:
                        i = 440892370;
                        break;
                    case true:
                        i = 797964446;
                        break;
                    case true:
                        i = -340243438;
                        break;
                    case true:
                        i = 549204015;
                        break;
                    case true:
                        i = 1685191368;
                        break;
                    case true:
                        i = 603469251;
                        break;
                    case true:
                        i = -281105389;
                        break;
                    case true:
                        i = 1533295406;
                        break;
                    case true:
                        i = 1694955673;
                        break;
                    case true:
                        i = -456004137;
                        break;
                    case true:
                        i = -832279536;
                        break;
                    case true:
                        i = -560365681;
                        break;
                    case true:
                        i = -1107888141;
                        break;
                    case true:
                        i = 242845117;
                        break;
                    case true:
                        i = -863640937;
                        break;
                    case true:
                        i = -1232152329;
                        break;
                    case true:
                        i = 1025574910;
                        break;
                    case true:
                        i = -323747775;
                        break;
                    case true:
                        i = -697942276;
                        break;
                    default:
                        i = 454475866;
                        break;
                }
                int i3 = i2;
                i2++;
                bytes[i3] = (byte) i;
            } while (i2 != length);
            Cipher cipher = Cipher.getInstance("DES/CBC/PKCS5Padding");
            cipher.init(2, SecretKeyFactory.getInstance("DES").generateSecret(new DESKeySpec(bytes2)), new IvParameterSpec(new byte[8]));
            byte[] doFinal = cipher.doFinal(bytes);
            int length2 = doFinal.length;
            MessageDigest messageDigest = MessageDigest.getInstance("SHA-256");
            messageDigest.reset();
            int i4 = length2 - 32;
            messageDigest.update(doFinal, 0, i4);
            byte[] digest = messageDigest.digest();
            int i5 = 0;
            Object[] objArr = false;
            int i6 = 0;
            do {
                objArr = (objArr == true ? 1 : 0) | (doFinal[i4 + i5] ^ digest[i5]) ? 1 : 0;
                i5++;
            } while (i5 != 32);
            if (objArr == false) {
                Object[] objArr2 = new Object[3];
                a = objArr2;
                int i7 = 0;
                do {
                    int i8 = i7;
                    int i9 = i7 + 1;
                    int i10 = i9 + 1;
                    int i11 = (doFinal[i8] & 255) | ((doFinal[i9] & 255) << 8);
                    byte[] bArr = new byte[i11];
                    System.arraycopy(doFinal, i10, bArr, 0, i11);
                    i7 = i10 + i11;
                    int i12 = i6;
                    i6++;
                    objArr2[i12] = new String(bArr, "UTF-8").intern();
                } while (i7 != i4);
            }
            X = new Axis((String) a((char) 1206517760), 0) { // from class: cn.dg32z.lon.utils.nmsutil.Collisions.Axis.1
                /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
                @Override // cn.dg32z.lon.utils.nmsutil.Collisions.Axis
                public Direction getPositive() {
                    return Direction.EAST;
                }

                /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
                @Override // cn.dg32z.lon.utils.nmsutil.Collisions.Axis
                public double choose(double d, double d2, double d3) {
                    return d;
                }
            };
            Y = new Axis((String) a((char) (-362938367)), 1) { // from class: cn.dg32z.lon.utils.nmsutil.Collisions.Axis.2
                /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
                @Override // cn.dg32z.lon.utils.nmsutil.Collisions.Axis
                public Direction getPositive() {
                    return Direction.UP;
                }

                /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
                @Override // cn.dg32z.lon.utils.nmsutil.Collisions.Axis
                public double choose(double d, double d2, double d3) {
                    return d2;
                }
            };
            Z = new Axis((String) a((char) 130940930), 2) { // from class: cn.dg32z.lon.utils.nmsutil.Collisions.Axis.3
                /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
                @Override // cn.dg32z.lon.utils.nmsutil.Collisions.Axis
                public Direction getPositive() {
                    return Direction.SOUTH;
                }

                /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
                @Override // cn.dg32z.lon.utils.nmsutil.Collisions.Axis
                public double choose(double d, double d2, double d3) {
                    return d3;
                }
            };
            $VALUES = $values();
        }

        /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
        private static /* synthetic */ Axis[] $values() {
            return new Axis[]{X, Y, Z};
        }

        public abstract double choose(double d, double d2, double d3);

        private Axis(String str, int i) {
        }

        public abstract Direction getPositive();

        /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
        public static Axis valueOf(String str) {
            return (Axis) Enum.valueOf(Axis.class, str);
        }

        /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
        public static Axis[] values() {
            return (Axis[]) $VALUES.clone();
        }

        private static Object a(char c) {
            return ((Object[]) a)[c];
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:10:0x0208, code lost:
    
        if ((1496.0328f - 9.009089f) != 1487.0238f) goto L13;
     */
    /* JADX WARN: Code restructure failed: missing block: B:12:0x007a, code lost:
    
        if (r18 > r15.getBlockZ()) goto L28;
     */
    /* JADX WARN: Code restructure failed: missing block: B:14:0x0085, code lost:
    
        if ((1271.5424f - 13.180085f) != 1258.3623f) goto L51;
     */
    /* JADX WARN: Code restructure failed: missing block: B:16:0x01a6, code lost:
    
        if (r16 > r15.getBlockX()) goto L11;
     */
    /* JADX WARN: Code restructure failed: missing block: B:17:0x005a, code lost:
    
        return;
     */
    /* JADX WARN: Code restructure failed: missing block: B:19:0x01b4, code lost:
    
        if ((736.8582763671875d - 0.6d) != 736.2583f) goto L25;
     */
    /* JADX WARN: Code restructure failed: missing block: B:20:0x00c8, code lost:
    
        r17 = r14.getBlockY();
     */
    /* JADX WARN: Code restructure failed: missing block: B:21:0x00da, code lost:
    
        if ((1313.971435546875d - 0.4d) != 1313.5714f) goto L74;
     */
    /* JADX WARN: Code restructure failed: missing block: B:23:0x022d, code lost:
    
        if (r17 > r15.getBlockY()) goto L67;
     */
    /* JADX WARN: Code restructure failed: missing block: B:24:0x01f9, code lost:
    
        r16 = r16 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:26:0x0238, code lost:
    
        if ((542.5797f - 11.40968f) == 531.17004f) goto L79;
     */
    /* JADX WARN: Code restructure failed: missing block: B:27:0x023e, code lost:
    
        r18 = r14.getBlockZ();
     */
    /* JADX WARN: Code restructure failed: missing block: B:28:0x024d, code lost:
    
        if ((880.15356f - 7.7991467f) != 872.35443f) goto L64;
     */
    /* JADX WARN: Code restructure failed: missing block: B:29:0x01e4, code lost:
    
        r16 = r14.getBlockX();
     */
    /* JADX WARN: Code restructure failed: missing block: B:30:0x01f3, code lost:
    
        if ((935.7589f - 11.742064f) == 924.01685f) goto L51;
     */
    /* JADX WARN: Code restructure failed: missing block: B:31:0x0156, code lost:
    
        onInsideBlock(r10, r20, r19, r16, r17, r18);
     */
    /* JADX WARN: Code restructure failed: missing block: B:32:0x016f, code lost:
    
        if ((517.9970703125d - 0.8d) == 517.1971f) goto L29;
     */
    /* JADX WARN: Code restructure failed: missing block: B:33:0x008c, code lost:
    
        r18 = r18 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:34:0x00e6, code lost:
    
        r0 = r10.boundingBox.copy().expand(-r11);
     */
    /* JADX WARN: Code restructure failed: missing block: B:35:0x00fd, code lost:
    
        if ((827.8111572265625d - 0.6d) == 827.2112f) goto L35;
     */
    /* JADX WARN: Code restructure failed: missing block: B:36:0x0111, code lost:
    
        r13 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:37:0x011d, code lost:
    
        if ((841.874267578125d - 0.8d) != 841.0743f) goto L47;
     */
    /* JADX WARN: Code restructure failed: missing block: B:38:0x0175, code lost:
    
        r14 = new org.bukkit.Location((org.bukkit.World) null, r13.minX, r13.minY, r13.minZ);
     */
    /* JADX WARN: Code restructure failed: missing block: B:39:0x0196, code lost:
    
        if ((1445.314697265625d - 0.2d) != 1445.1147f) goto L3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:40:0x001e, code lost:
    
        r15 = new org.bukkit.Location((org.bukkit.World) null, r13.maxX, r13.maxY, r13.maxZ);
     */
    /* JADX WARN: Code restructure failed: missing block: B:41:0x003f, code lost:
    
        if ((1025.896484375d - 0.1d) == 1025.7965f) goto L64;
     */
    /* JADX WARN: Code restructure failed: missing block: B:43:0x00b4, code lost:
    
        if (cn.dg32z.lon.utils.nmsutil.CheckIfChunksLoaded.isChunksUnloadedAt(r10, r14.getBlockX(), r14.getBlockY(), r14.getBlockZ(), r15.getBlockX(), r15.getBlockY(), r15.getBlockZ()) == false) goto L64;
     */
    /* JADX WARN: Code restructure failed: missing block: B:45:0x00c2, code lost:
    
        if ((615.7465209960938d - 0.4d) != 615.3465f) goto L18;
     */
    /* JADX WARN: Code restructure failed: missing block: B:46:0x008b, code lost:
    
        return;
     */
    /* JADX WARN: Code restructure failed: missing block: B:47:0x020e, code lost:
    
        r20 = r19.getType();
     */
    /* JADX WARN: Code restructure failed: missing block: B:48:0x0220, code lost:
    
        if ((1232.700927734375d - 0.9d) == 1231.8009f) goto L64;
     */
    /* JADX WARN: Code restructure failed: missing block: B:50:0x01d3, code lost:
    
        if (r20.isAir() == false) goto L44;
     */
    /* JADX WARN: Code restructure failed: missing block: B:52:0x01de, code lost:
    
        if ((1494.8704f - 12.828501f) != 1482.0419f) goto L44;
     */
    /* JADX WARN: Code restructure failed: missing block: B:53:0x0073, code lost:
    
        r18 = r18 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:54:0x00e0, code lost:
    
        r17 = r17 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:55:?, code lost:
    
        return;
     */
    /* JADX WARN: Code restructure failed: missing block: B:56:0x0123, code lost:
    
        r19 = r10.compensatedWorld.getWrappedBlockStateAt(r16, r17, r18);
     */
    /* JADX WARN: Code restructure failed: missing block: B:57:0x013d, code lost:
    
        if ((1497.90380859375d - 0.8d) != 1497.1038f) goto L71;
     */
    /* JADX WARN: Code restructure failed: missing block: B:58:0x0226, code lost:
    
        r17 = r17 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:60:0x0049, code lost:
    
        if (r10.isRiding() == false) goto L29;
     */
    /* JADX WARN: Code restructure failed: missing block: B:62:0x0054, code lost:
    
        if ((1255.1245f - 6.537672f) == 1248.5868f) goto L12;
     */
    /* JADX WARN: Code restructure failed: missing block: B:63:0x005b, code lost:
    
        r0 = cn.dg32z.lon.utils.nmsutil.GetBoundingBox.getCollisionBoxForPlayer(r10, r10.x, r10.y, r10.z).expand(-r11);
     */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:24:0x01f9 -> B:15:0x019f). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:28:0x024d -> B:11:0x0073). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:30:0x01f3 -> B:15:0x019f). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:41:0x003f -> B:29:0x01e4). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:43:0x00b4 -> B:29:0x01e4). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:45:0x00c2 -> B:46:0x020e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:47:0x0220 -> B:29:0x01e4). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:59:0x0054 -> B:20:0x00c8). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:62:0x01c8 -> B:9:0x01ff). Please report as a decompilation issue!!! */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static void handleInsideBlocks(cn.dg32z.lon.player.PlayerData r10) {
        /*
            Method dump skipped, instructions count: 596
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.handleInsideBlocks(cn.dg32z.lon.player.PlayerData):void");
    }

    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    public static Iterable axisStepOrder(Vector vector) {
        if (Math.abs(vector.getX()) < Math.abs(vector.getZ())) {
            return YZX_AXIS_ORDER;
        }
        ImmutableList immutableList = YXZ_AXIS_ORDER;
        if (1238.7027587890625d - 0.6d == 1238.1028f) {
        }
        return immutableList;
    }

    /*  JADX ERROR: IndexOutOfBoundsException in pass: SSATransform
        java.lang.IndexOutOfBoundsException: bitIndex < 0: -1
        	at java.base/java.util.BitSet.get(BitSet.java:628)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.fillBasicBlockInfo(LiveVarAnalysis.java:65)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.runAnalysis(LiveVarAnalysis.java:36)
        	at jadx.core.dex.visitors.ssa.SSATransform.process(SSATransform.java:58)
        	at jadx.core.dex.visitors.ssa.SSATransform.visit(SSATransform.java:44)
        */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:16:0x0174 -> B:7:0x00a6). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:18:0x01a2 -> B:9:0x00d4). Please report as a decompilation issue!!! */
    static {
        /*
            Method dump skipped, instructions count: 531
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.m5clinit():void");
    }

    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    public static boolean onClimbable(PlayerData playerData, double d, double d2, double d3) {
        loop0: do {
            WrappedBlockState wrappedBlockStateAt = playerData.compensatedWorld.getWrappedBlockStateAt(d, d2, d3);
            if (1038.5322f - 10.08754f == 1028.4447f) {
                StateType type = wrappedBlockStateAt.getType();
                if (643.2035522460938d - 0.4d == 642.8035f) {
                }
                while (type != StateTypes.CAVE_VINES) {
                    if (type == StateTypes.CAVE_VINES_PLANT) {
                        if (719.1796875d - 0.7d != 718.4797f) {
                            break loop0;
                        }
                    } else if (playerData.tagManager.block(SyncedTags.CLIMBABLE).contains(type)) {
                    }
                    if (type == StateTypes.SWEET_BERRY_BUSH && playerData.getClientVersion().isOlderThan(ClientVersion.V_1_14)) {
                        if (975.77795f - 10.242386f == 965.5356f) {
                            return true;
                        }
                    }
                }
                return playerData.getClientVersion().isNewerThanOrEquals(ClientVersion.V_1_17);
            }
            return trapdoorUsableAsLadder(playerData, d, d2, d3, wrappedBlockStateAt);
        } while (581.2923583984375d - 0.7d == 580.59235f);
        return true;
    }

    /*  JADX ERROR: IndexOutOfBoundsException in pass: SSATransform
        java.lang.IndexOutOfBoundsException: bitIndex < 0: -1
        	at java.base/java.util.BitSet.get(BitSet.java:628)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.fillBasicBlockInfo(LiveVarAnalysis.java:65)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.runAnalysis(LiveVarAnalysis.java:36)
        	at jadx.core.dex.visitors.ssa.SSATransform.process(SSATransform.java:58)
        	at jadx.core.dex.visitors.ssa.SSATransform.visit(SSATransform.java:44)
        */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:103:0x026b -> B:10:0x0349). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:111:0x0330 -> B:94:0x0554). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:115:0x059e -> B:12:0x0060). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:117:0x05ad -> B:96:0x02c7). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:141:0x0460 -> B:65:0x02ff). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:44:0x03d7 -> B:12:0x0060). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:48:0x0285 -> B:49:0x0336). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:57:0x00f5 -> B:108:0x031a). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:64:0x0299 -> B:65:0x02ff). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:66:0x0314 -> B:67:0x00ab). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:73:0x05b7 -> B:12:0x0060). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:75:0x05c5 -> B:8:0x020e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:7:0x03c3 -> B:4:0x01e5). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:82:0x00a5 -> B:78:0x00c4). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:86:0x02c1 -> B:6:0x03ae). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:88:0x017f -> B:10:0x0349). Please report as a decompilation issue!!! */
    public static void addCollisionsAlongTravel(java.util.Set r15, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d r16, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d r17, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox r18) {
        /*
            Method dump skipped, instructions count: 1484
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.addCollisionsAlongTravel(java.util.Set, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox):void");
    }

    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    public static Vector collide(PlayerData playerData, double d, double d2, double d3) {
        return collide(playerData, d, d2, d3, d2, null);
    }

    /*  JADX ERROR: IndexOutOfBoundsException in pass: SSATransform
        java.lang.IndexOutOfBoundsException: bitIndex < 0: -1
        	at java.base/java.util.BitSet.get(BitSet.java:628)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.fillBasicBlockInfo(LiveVarAnalysis.java:65)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.runAnalysis(LiveVarAnalysis.java:36)
        	at jadx.core.dex.visitors.ssa.SSATransform.process(SSATransform.java:58)
        	at jadx.core.dex.visitors.ssa.SSATransform.visit(SSATransform.java:44)
        */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    public static boolean doesBlockSuffocate(cn.dg32z.lon.player.PlayerData r8, int r9, int r10, int r11) {
        /*
            Method dump skipped, instructions count: 627
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.doesBlockSuffocate(cn.dg32z.lon.player.PlayerData, int, int, int):boolean");
    }

    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    public static double getHorizontalDistanceSqr(Vector vector) {
        return (vector.getX() * vector.getX()) + (vector.getZ() * vector.getZ());
    }

    /* JADX WARN: Code restructure failed: missing block: B:11:0x0146, code lost:
    
        if ((881.2329711914062d - 0.8d) == 880.433f) goto L23;
     */
    /* JADX WARN: Code restructure failed: missing block: B:12:0x0091, code lost:
    
        r13 = r8.compensatedWorld.getWrappedBlockStateAt(r12, r10, r11);
     */
    /* JADX WARN: Code restructure failed: missing block: B:13:0x00a9, code lost:
    
        if ((1109.3867f - 9.1875925f) != 1100.1991f) goto L34;
     */
    /* JADX WARN: Code restructure failed: missing block: B:14:0x00e7, code lost:
    
        r0 = cn.dg32z.lon.utils.collisions.CollisionData.getData(r13.getType()).getMovementCollisionBox(r8, r8.getClientVersion(), r13, r12, r10, r11);
     */
    /* JADX WARN: Code restructure failed: missing block: B:15:0x010a, code lost:
    
        if ((597.8895f - 6.6179237f) != 591.2716f) goto L47;
     */
    /* JADX WARN: Code restructure failed: missing block: B:17:0x0154, code lost:
    
        if (r0.isIntersected(r9) != false) goto L55;
     */
    /* JADX WARN: Code restructure failed: missing block: B:18:0x015a, code lost:
    
        r12 = r12 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:20:?, code lost:
    
        return true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:24:0x0046, code lost:
    
        if (r12 >= java.lang.Math.ceil(r9.maxX)) goto L63;
     */
    /* JADX WARN: Code restructure failed: missing block: B:26:0x0054, code lost:
    
        if ((1492.2799f - 8.734029f) == 1483.5459f) goto L18;
     */
    /* JADX WARN: Code restructure failed: missing block: B:28:0x007d, code lost:
    
        if (doesBlockSuffocate(r8, r12, r10, r11) == false) goto L50;
     */
    /* JADX WARN: Code restructure failed: missing block: B:30:0x008b, code lost:
    
        if ((1499.2363f - 8.410501f) != 1490.8258f) goto L61;
     */
    /* JADX WARN: Code restructure failed: missing block: B:32:0x011a, code lost:
    
        if (r8.getClientVersion().isNewerThanOrEquals(cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion.V_1_16) == false) goto L56;
     */
    /* JADX WARN: Code restructure failed: missing block: B:34:0x0128, code lost:
    
        if ((597.95593f - 9.505418f) == 588.4505f) goto L64;
     */
    /* JADX WARN: Code restructure failed: missing block: B:38:?, code lost:
    
        return true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:39:0x00af, code lost:
    
        continue;
     */
    /* JADX WARN: Code restructure failed: missing block: B:41:0x003b, code lost:
    
        r12 = r12 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:9:0x006f, code lost:
    
        if ((1284.468994140625d - 0.9d) != 1283.569f) goto L4;
     */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:34:0x002f -> B:10:0x0130). Please report as a decompilation issue!!! */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static boolean suffocatesAt(cn.dg32z.lon.player.PlayerData r8, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox r9) {
        /*
            Method dump skipped, instructions count: 356
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.suffocatesAt(cn.dg32z.lon.player.PlayerData, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox):boolean");
    }

    /*  JADX ERROR: IndexOutOfBoundsException in pass: SSATransform
        java.lang.IndexOutOfBoundsException: bitIndex < 0: -1
        	at java.base/java.util.BitSet.set(BitSet.java:449)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.fillBasicBlockInfo(LiveVarAnalysis.java:73)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.runAnalysis(LiveVarAnalysis.java:36)
        	at jadx.core.dex.visitors.ssa.SSATransform.process(SSATransform.java:58)
        	at jadx.core.dex.visitors.ssa.SSATransform.visit(SSATransform.java:44)
        */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:111:0x0493 -> B:17:0x051c). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:111:0x0493 -> B:29:0x010d). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:115:0x03e8 -> B:10:0x0078). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:123:0x0560 -> B:19:0x0218). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:128:0x0453 -> B:15:0x0587). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:128:0x0453 -> B:76:0x01c0). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:13:0x008a -> B:6:0x0036). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:14:0x0141 -> B:6:0x0036). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:16:0x05ae -> B:6:0x0036). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:30:0x0124 -> B:6:0x0036). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:39:0x02e2 -> B:31:0x0240). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:42:0x0394 -> B:6:0x0036). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:51:0x0107 -> B:36:0x02c1). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:51:0x0107 -> B:52:0x0309). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:55:0x013b -> B:58:0x0184). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:63:0x01a3 -> B:6:0x0036). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:65:0x0274 -> B:19:0x0218). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:65:0x0274 -> B:66:0x01e6). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:73:0x0212 -> B:36:0x02c1). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:75:0x01ba -> B:116:0x027a). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:75:0x01ba -> B:58:0x0184). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:85:0x02bb -> B:31:0x0240). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:93:0x0303 -> B:52:0x0309). Please report as a decompilation issue!!! */
    public static void onInsideBlock(cn.dg32z.lon.player.PlayerData r10, cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.type.StateType r11, cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.WrappedBlockState r12, int r13, int r14, int r15) {
        /*
            Method dump skipped, instructions count: 1461
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.onInsideBlock(cn.dg32z.lon.player.PlayerData, cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.type.StateType, cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.WrappedBlockState, int, int, int):void");
    }

    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    public static boolean isEmpty(PlayerData playerData, SimpleCollisionBox simpleCollisionBox) {
        if (!getCollisionBoxes(playerData, simpleCollisionBox, null, true)) {
            return true;
        }
        if (1390.2522f - 10.3001995f != 1379.952f) {
        }
        return false;
    }

    /* JADX WARN: Code restructure failed: missing block: B:100:0x014b, code lost:
    
        if (r12 <= 0.0d) goto L132;
     */
    /* JADX WARN: Code restructure failed: missing block: B:102:0x0159, code lost:
    
        if ((919.3143f - 6.187026f) != 913.12726f) goto L82;
     */
    /* JADX WARN: Code restructure failed: missing block: B:103:0x0114, code lost:
    
        r14 = r14 - 0.05d;
     */
    /* JADX WARN: Code restructure failed: missing block: B:105:0x0186, code lost:
    
        r12 = r12 - 0.05d;
     */
    /* JADX WARN: Code restructure failed: missing block: B:107:0x0292, code lost:
    
        r12 = r12 + 0.05d;
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:108:0x02a4, code lost:
    
        if ((1309.197021484375d - 0.3d) == 1308.897f) goto L81;
     */
    /* JADX WARN: Code restructure failed: missing block: B:10:0x00ec, code lost:
    
        r14 = r14 - 0.05d;
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:113:0x0011, code lost:
    
        r12 = r9.getX();
     */
    /* JADX WARN: Code restructure failed: missing block: B:114:0x0021, code lost:
    
        if ((577.1854f - 13.845545f) != 563.3399f) goto L130;
     */
    /* JADX WARN: Code restructure failed: missing block: B:11:0x018f, code lost:
    
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:12:0x0193, code lost:
    
        if (r14 == 0.0d) goto L138;
     */
    /* JADX WARN: Code restructure failed: missing block: B:13:0x0196, code lost:
    
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:14:0x01a9, code lost:
    
        if (isEmpty(r10, r10.boundingBox.copy().offset(0.0d, r16, r14)) == false) goto L138;
     */
    /* JADX WARN: Code restructure failed: missing block: B:15:0x01ac, code lost:
    
        r0 = r0;
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:16:0x01b8, code lost:
    
        if ((618.9265747070312d - 0.7d) != 618.22656f) goto L97;
     */
    /* JADX WARN: Code restructure failed: missing block: B:18:0x0252, code lost:
    
        if (r14 >= 0.05d) goto L114;
     */
    /* JADX WARN: Code restructure failed: missing block: B:20:0x025b, code lost:
    
        if (r14 < (-0.05d)) goto L114;
     */
    /* JADX WARN: Code restructure failed: missing block: B:21:0x025e, code lost:
    
        r0 = r0;
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:22:0x026a, code lost:
    
        if ((750.3136596679688d - 0.2d) != 750.11365f) goto L81;
     */
    /* JADX WARN: Code restructure failed: missing block: B:23:0x01d2, code lost:
    
        r14 = 0.0d;
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:25:0x0275, code lost:
    
        if (r12 >= 0.05d) goto L31;
     */
    /* JADX WARN: Code restructure failed: missing block: B:27:0x00ac, code lost:
    
        if (r12 <= 0.0d) goto L96;
     */
    /* JADX WARN: Code restructure failed: missing block: B:29:0x00ba, code lost:
    
        if ((1129.9661f - 13.093462f) == 1116.8726f) goto L46;
     */
    /* JADX WARN: Code restructure failed: missing block: B:30:0x010b, code lost:
    
        r12 = r12 - 0.05d;
     */
    /* JADX WARN: Code restructure failed: missing block: B:31:0x00c0, code lost:
    
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:32:0x00c3, code lost:
    
        if (r12 == 0.0d) goto L71;
     */
    /* JADX WARN: Code restructure failed: missing block: B:33:0x00c6, code lost:
    
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:34:0x00d8, code lost:
    
        if (isEmpty(r10, r10.boundingBox.copy().offset(r12, r16, 0.0d)) == false) goto L71;
     */
    /* JADX WARN: Code restructure failed: missing block: B:35:0x00db, code lost:
    
        r0 = r0;
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:36:0x00e6, code lost:
    
        if ((1042.1729f - 11.495354f) == 1030.6775f) goto L104;
     */
    /* JADX WARN: Code restructure failed: missing block: B:37:0x0227, code lost:
    
        r14 = r9.getZ();
        r0 = ((824.498f - 8.83779f) > 815.6602f ? 1 : ((824.498f - 8.83779f) == 815.6602f ? 0 : -1));
     */
    /* JADX WARN: Code restructure failed: missing block: B:38:0x0238, code lost:
    
        if (r0 == 0) goto L24;
     */
    /* JADX WARN: Code restructure failed: missing block: B:39:0x0086, code lost:
    
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:40:0x0087, code lost:
    
        if (r11 != false) goto L45;
     */
    /* JADX WARN: Code restructure failed: missing block: B:42:0x0094, code lost:
    
        if (r10.getClientVersion().isNewerThanOrEquals(cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion.V_1_11) == false) goto L13;
     */
    /* JADX WARN: Code restructure failed: missing block: B:43:0x004a, code lost:
    
        r0 = -0.9999999d;
     */
    /* JADX WARN: Code restructure failed: missing block: B:44:0x0059, code lost:
    
        if ((690.97998046875d - 0.8d) == 690.18f) goto L78;
     */
    /* JADX WARN: Code restructure failed: missing block: B:45:0x01be, code lost:
    
        r16 = r0;
        r0 = ((746.1219482421875d - 0.1d) > 746.022f ? 1 : ((746.1219482421875d - 0.1d) == 746.022f ? 0 : -1));
     */
    /* JADX WARN: Code restructure failed: missing block: B:46:0x01cc, code lost:
    
        if (r0 == 0) goto L13;
     */
    /* JADX WARN: Code restructure failed: missing block: B:47:0x0097, code lost:
    
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:48:0x00a3, code lost:
    
        if ((1276.339111328125d - 0.2d) == 1276.1392f) goto L23;
     */
    /* JADX WARN: Code restructure failed: missing block: B:49:0x0081, code lost:
    
        r12 = 0.0d;
     */
    /* JADX WARN: Code restructure failed: missing block: B:51:0x002d, code lost:
    
        if (r14 >= 0.05d) goto L84;
     */
    /* JADX WARN: Code restructure failed: missing block: B:53:0x0036, code lost:
    
        if (r14 < (-0.05d)) goto L84;
     */
    /* JADX WARN: Code restructure failed: missing block: B:55:0x0044, code lost:
    
        if ((951.36993f - 5.4692802f) == 945.90063f) goto L119;
     */
    /* JADX WARN: Code restructure failed: missing block: B:56:0x02c3, code lost:
    
        r0 = 0;
        r14 = 0.0d;
     */
    /* JADX WARN: Code restructure failed: missing block: B:57:0x0207, code lost:
    
        r9 = new org.bukkit.util.Vector(r12, r9.getY(), r14);
     */
    /* JADX WARN: Code restructure failed: missing block: B:58:0x0221, code lost:
    
        if ((564.4375f - 8.996288f) != 555.4412f) goto L23;
     */
    /* JADX WARN: Code restructure failed: missing block: B:63:0x01ee, code lost:
    
        r0 = (r14 > 0.0d ? 1 : (r14 == 0.0d ? 0 : -1));
     */
    /* JADX WARN: Code restructure failed: missing block: B:64:0x01f2, code lost:
    
        if (r0 <= 0) goto L83;
     */
    /* JADX WARN: Code restructure failed: missing block: B:65:0x01e3, code lost:
    
        r14 = r14 + 0.05d;
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:66:0x01f5, code lost:
    
        r0 = ((1249.33154296875d - 0.2d) > 1249.1316f ? 1 : ((1249.33154296875d - 0.2d) == 1249.1316f ? 0 : -1));
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:67:0x0201, code lost:
    
        if (r0 == 0) goto L97;
     */
    /* JADX WARN: Code restructure failed: missing block: B:68:0x01d8, code lost:
    
        r14 = r14 - 0.05d;
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:69:0x00c0, code lost:
    
        r12 = r12 + 0.05d;
     */
    /* JADX WARN: Code restructure failed: missing block: B:70:0x0243, code lost:
    
        r12 = r12 + 0.05d;
     */
    /* JADX WARN: Code restructure failed: missing block: B:72:0x027d, code lost:
    
        if (r12 < (-0.05d)) goto L31;
     */
    /* JADX WARN: Code restructure failed: missing block: B:74:0x028c, code lost:
    
        if ((1328.0772705078125d - 0.9d) != 1327.1772f) goto L95;
     */
    /* JADX WARN: Code restructure failed: missing block: B:75:0x023e, code lost:
    
        r12 = 0.0d;
     */
    /* JADX WARN: Code restructure failed: missing block: B:77:0x02ae, code lost:
    
        if (r14 <= 0.0d) goto L44;
     */
    /* JADX WARN: Code restructure failed: missing block: B:78:0x00f7, code lost:
    
        r14 = r14 + 0.05d;
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:79:0x02b1, code lost:
    
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:80:0x02bd, code lost:
    
        if ((518.4815063476562d - 0.4d) == 518.0815f) goto L92;
     */
    /* JADX WARN: Code restructure failed: missing block: B:81:0x0102, code lost:
    
        r1 = -r10.getMaxUpStep();
        r0 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:84:0x0117, code lost:
    
        if (r12 == 0.0d) goto L135;
     */
    /* JADX WARN: Code restructure failed: missing block: B:86:0x011e, code lost:
    
        if (r14 == 0.0d) goto L137;
     */
    /* JADX WARN: Code restructure failed: missing block: B:88:0x0134, code lost:
    
        if (isEmpty(r10, r10.boundingBox.copy().offset(r12, r16, r14)) == false) goto L134;
     */
    /* JADX WARN: Code restructure failed: missing block: B:90:0x0142, code lost:
    
        if ((574.9196f - 6.953464f) != 567.9661f) goto L131;
     */
    /* JADX WARN: Code restructure failed: missing block: B:92:0x0064, code lost:
    
        if (r12 >= 0.05d) goto L56;
     */
    /* JADX WARN: Code restructure failed: missing block: B:94:0x006c, code lost:
    
        if (r12 < (-0.05d)) goto L56;
     */
    /* JADX WARN: Code restructure failed: missing block: B:97:0x007b, code lost:
    
        if ((602.857177734375d - 0.8d) != 602.0572f) goto L23;
     */
    /* JADX WARN: Code restructure failed: missing block: B:98:0x00c0, code lost:
    
        r12 = 0.0d;
     */
    /* JADX WARN: Code restructure failed: missing block: B:9:0x0180, code lost:
    
        if (r0 != 0) goto L3;
     */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v36 */
    /* JADX WARN: Type inference failed for: r0v47 */
    /* JADX WARN: Type inference failed for: r0v71 */
    /* JADX WARN: Type inference failed for: r0v72 */
    /* JADX WARN: Type inference failed for: r0v73 */
    /* JADX WARN: Type inference failed for: r0v74 */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:34:0x02c3 -> B:13:0x0114). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:37:0x01e3 -> B:13:0x0114). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:45:0x026a -> B:47:0x0270). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:46:0x01d2 -> B:11:0x018f). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:52:0x00ba -> B:60:0x0227). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:53:0x010b -> B:54:0x00c0). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:55:0x00c3 -> B:11:0x018f). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:57:0x00d8 -> B:11:0x018f). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:69:0x01cc -> B:66:0x004a). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:80:0x00f7 -> B:11:0x018f). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:82:0x02bd -> B:10:0x00ec). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:82:0x02bd -> B:60:0x0227). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:93:0x0221 -> B:27:0x0081). Please report as a decompilation issue!!! */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static org.bukkit.util.Vector maybeBackOffFromEdge(org.bukkit.util.Vector r9, cn.dg32z.lon.player.PlayerData r10, boolean r11) {
        /*
            Method dump skipped, instructions count: 717
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.maybeBackOffFromEdge(org.bukkit.util.Vector, cn.dg32z.lon.player.PlayerData, boolean):org.bukkit.util.Vector");
    }

    /*  JADX ERROR: IndexOutOfBoundsException in pass: SSATransform
        java.lang.IndexOutOfBoundsException: bitIndex < 0: -1
        	at java.base/java.util.BitSet.set(BitSet.java:449)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.fillBasicBlockInfo(LiveVarAnalysis.java:73)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.runAnalysis(LiveVarAnalysis.java:36)
        	at jadx.core.dex.visitors.ssa.SSATransform.process(SSATransform.java:58)
        	at jadx.core.dex.visitors.ssa.SSATransform.visit(SSATransform.java:44)
        */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:100:0x04ed -> B:16:0x0707). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:100:0x04ed -> B:70:0x0552). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:102:0x0321 -> B:103:0x009d). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:106:0x05a4 -> B:56:0x0127). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:108:0x05a9 -> B:56:0x0127). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:112:0x018a -> B:8:0x07a2). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:114:0x05be -> B:56:0x0127). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:122:0x079c -> B:56:0x0127). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:139:0x072b -> B:56:0x0127). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:141:0x0740 -> B:40:0x0483). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:143:0x0676 -> B:83:0x07e0). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:145:0x057e -> B:32:0x0142). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:147:0x039a -> B:40:0x0483). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:158:0x0273 -> B:30:0x0434). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:164:0x0063 -> B:32:0x0142). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:170:0x0513 -> B:144:0x0572). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:172:0x0521 -> B:153:0x0446). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:178:0x0379 -> B:77:0x0549). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:183:0x0537 -> B:8:0x07a2). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:185:0x011b -> B:79:0x081a). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:212:0x062b -> B:14:0x02d5). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:41:0x04a1 -> B:8:0x07a2). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:69:0x0212 -> B:56:0x0127). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:80:0x0825 -> B:56:0x0127). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:88:0x047d -> B:26:0x03ce). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:92:0x04da -> B:16:0x0707). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:92:0x04da -> B:58:0x07c1). Please report as a decompilation issue!!! */
    public static org.bukkit.util.Vector collide(cn.dg32z.lon.player.PlayerData r16, double r17, double r19, double r21, double r23, cn.dg32z.lon.utils.data.VectorData r25) {
        /*
            Method dump skipped, instructions count: 2122
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.collide(cn.dg32z.lon.player.PlayerData, double, double, double, double, cn.dg32z.lon.utils.data.VectorData):org.bukkit.util.Vector");
    }

    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    public static Vector3d relative(Vector3d vector3d, Direction direction, double d) {
        Vector3i vector;
        do {
            vector = direction.getVector();
        } while (1395.3091f - 8.809654f != 1386.4994f);
        double d2 = vector3d.x;
        if (1104.426513671875d - 0.9d != 1103.5265f) {
        }
        Vector3d vector3d2 = new Vector3d(d2 + (d * vector.getX()), vector3d.y + (d * vector.getY()), vector3d.z + (d * vector.getZ()));
        if (763.2465209960938d - 0.6d != 762.64655f) {
        }
        return vector3d2;
    }

    /*  JADX ERROR: IndexOutOfBoundsException in pass: SSATransform
        java.lang.IndexOutOfBoundsException: bitIndex < 0: -1
        	at java.base/java.util.BitSet.get(BitSet.java:628)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.fillBasicBlockInfo(LiveVarAnalysis.java:65)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.runAnalysis(LiveVarAnalysis.java:36)
        	at jadx.core.dex.visitors.ssa.SSATransform.process(SSATransform.java:58)
        	at jadx.core.dex.visitors.ssa.SSATransform.visit(SSATransform.java:44)
        */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:101:0x0722 -> B:41:0x03fc). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:119:0x0607 -> B:39:0x031e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:123:0x00cc -> B:33:0x0429). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:127:0x0644 -> B:107:0x0139). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:127:0x0644 -> B:128:0x045c). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:131:0x0155 -> B:20:0x0251). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:135:0x0387 -> B:21:0x0277). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:139:0x06f5 -> B:107:0x0139). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:139:0x06f5 -> B:77:0x06be). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:141:0x0218 -> B:144:0x0198). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:143:0x039e -> B:33:0x0429). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:143:0x039e -> B:6:0x0097). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:156:0x00af -> B:75:0x060d). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:160:0x02f2 -> B:68:0x03e3). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:168:0x01e6 -> B:198:0x030b). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:171:0x06c5 -> B:103:0x04b5). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:176:0x02dd -> B:18:0x05d0). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:178:0x00ee -> B:105:0x04f0). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:189:0x0365 -> B:105:0x04f0). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:26:0x0220 -> B:18:0x05d0). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:32:0x024b -> B:18:0x05d0). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:36:0x0496 -> B:10:0x0183). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:40:0x0330 -> B:8:0x0075). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:42:0x040b -> B:21:0x0277). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:44:0x04ea -> B:20:0x0251). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:46:0x0124 -> B:20:0x0251). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:48:0x0133 -> B:6:0x0097). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:50:0x02b2 -> B:10:0x0183). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:50:0x02b2 -> B:14:0x03c6). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:54:0x0423 -> B:14:0x03c6). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:59:0x00b5 -> B:14:0x03c6). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:71:0x03f6 -> B:72:0x0547). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:73:0x054b -> B:198:0x030b). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:80:0x011a -> B:103:0x04b5). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:84:0x029d -> B:103:0x04b5). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:93:0x03df -> B:83:0x0290). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:95:0x057c -> B:81:0x04c8). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:97:0x058b -> B:81:0x04c8). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:99:0x062d -> B:100:0x0713). Please report as a decompilation issue!!! */
    public static boolean getCollisionBoxes(cn.dg32z.lon.player.PlayerData r8, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox r9, java.util.List r10, boolean r11) {
        /*
            Method dump skipped, instructions count: 1834
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.getCollisionBoxes(cn.dg32z.lon.player.PlayerData, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox, java.util.List, boolean):boolean");
    }

    /* JADX WARN: Code restructure failed: missing block: B:10:0x00a2, code lost:
    
        r11 = (cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox) r10.next();
        r10 = r10;
        r10 = r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:11:0x00ba, code lost:
    
        if ((582.3716430664062d - 0.6d) == 581.77167f) goto L63;
     */
    /* JADX WARN: Code restructure failed: missing block: B:12:0x00c0, code lost:
    
        r12 = r11.getYPointPositions().iterator();
        r10 = r10;
        r10 = r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:13:0x00d7, code lost:
    
        if ((1385.5619f - 8.150421f) == 1377.4115f) goto L63;
     */
    /* JADX WARN: Code restructure failed: missing block: B:14:0x00dd, code lost:
    
        r0.add(r15);
        r10 = r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:15:0x00f2, code lost:
    
        if ((754.6381f - 10.844694f) != 743.79346f) goto L56;
     */
    /* JADX WARN: Code restructure failed: missing block: B:19:0x0075, code lost:
    
        if (r12.hasNext() == false) goto L58;
     */
    /* JADX WARN: Code restructure failed: missing block: B:20:0x0078, code lost:
    
        r0 = ((java.lang.Double) r12.next()).doubleValue();
     */
    /* JADX WARN: Code restructure failed: missing block: B:21:0x0092, code lost:
    
        if ((627.9896f - 11.211081f) != 616.77856f) goto L59;
     */
    /* JADX WARN: Code restructure failed: missing block: B:22:0x012f, code lost:
    
        r15 = (float) (r0 - r5.minY);
     */
    /* JADX WARN: Code restructure failed: missing block: B:23:0x0144, code lost:
    
        if ((891.3557f - 11.455602f) == 879.9001f) goto L62;
     */
    /* JADX WARN: Code restructure failed: missing block: B:25:0x004e, code lost:
    
        r10 = r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:26:0x0052, code lost:
    
        if (r15 < 0.0f) goto L63;
     */
    /* JADX WARN: Code restructure failed: missing block: B:27:0x0055, code lost:
    
        r10 = r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:28:0x0059, code lost:
    
        if (r15 == r8) goto L63;
     */
    /* JADX WARN: Code restructure failed: missing block: B:29:0x005c, code lost:
    
        r10 = r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:30:0x0068, code lost:
    
        if ((991.876953125d - 0.7d) != 991.17694f) goto L5;
     */
    /* JADX WARN: Code restructure failed: missing block: B:31:0x001c, code lost:
    
        r10 = r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:32:0x0020, code lost:
    
        if (r15 <= r7) goto L34;
     */
    /* JADX WARN: Code restructure failed: missing block: B:35:0x002e, code lost:
    
        if ((1111.5829f - 5.682702f) != 1105.9001f) goto L53;
     */
    /* JADX WARN: Code restructure failed: missing block: B:3:0x010e, code lost:
    
        if ((589.8824462890625d - 0.8d) == 589.08246f) goto L61;
     */
    /* JADX WARN: Code restructure failed: missing block: B:45:0x0114, code lost:
    
        r10 = r0.toFloatArray();
     */
    /* JADX WARN: Code restructure failed: missing block: B:46:0x0129, code lost:
    
        if ((1095.907470703125d - 0.4d) != 1095.5074f) goto L10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:47:0x0034, code lost:
    
        cn.dg32z.libs.it.unimi.dsi.fastutil.floats.FloatArrays.unstableSort((float[]) r10);
        r10 = r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:48:0x0045, code lost:
    
        if ((1328.3990478515625d - 0.6d) != 1327.7991f) goto L52;
     */
    /* JADX WARN: Code restructure failed: missing block: B:4:0x014d, code lost:
    
        r10 = r6.iterator();
        r10 = r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:5:0x0160, code lost:
    
        if ((647.4951f - 13.219745f) == 634.2754f) goto L61;
     */
    /* JADX WARN: Code restructure failed: missing block: B:9:0x009f, code lost:
    
        if (r10.hasNext() == false) goto L40;
     */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r10v12 */
    /* JADX WARN: Type inference failed for: r10v13 */
    /* JADX WARN: Type inference failed for: r10v19 */
    /* JADX WARN: Type inference failed for: r10v2 */
    /* JADX WARN: Type inference failed for: r10v20 */
    /* JADX WARN: Type inference failed for: r10v21 */
    /* JADX WARN: Type inference failed for: r10v22 */
    /* JADX WARN: Type inference failed for: r10v23 */
    /* JADX WARN: Type inference failed for: r10v3 */
    /* JADX WARN: Type inference failed for: r10v4, types: [float[]] */
    /* JADX WARN: Type inference failed for: r10v5 */
    /* JADX WARN: Type inference failed for: r10v6 */
    /* JADX WARN: Type inference failed for: r10v7 */
    /* JADX WARN: Type inference failed for: r10v8 */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:17:0x0052 -> B:10:0x006e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:19:0x0059 -> B:10:0x006e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:30:0x00f2 -> B:10:0x006e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:30:0x00f2 -> B:4:0x014d). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:32:0x00d7 -> B:10:0x006e). Please report as a decompilation issue!!! */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private static float[] collectStepHeights(cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox r5, java.util.List r6, float r7, float r8) {
        /*
            Method dump skipped, instructions count: 363
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.collectStepHeights(cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox, java.util.List, float, float):float[]");
    }

    /* JADX WARN: Code restructure failed: missing block: B:10:0x01e7, code lost:
    
        r22 = r11.iterator();
     */
    /* JADX WARN: Code restructure failed: missing block: B:11:0x01fa, code lost:
    
        if ((612.18994f - 9.367897f) != 602.822f) goto L14;
     */
    /* JADX WARN: Code restructure failed: missing block: B:13:0x006a, code lost:
    
        if (r22.hasNext() == false) goto L81;
     */
    /* JADX WARN: Code restructure failed: missing block: B:14:0x006d, code lost:
    
        r23 = (cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox) r22.next();
     */
    /* JADX WARN: Code restructure failed: missing block: B:15:0x0085, code lost:
    
        if ((1021.3449096679688d - 0.3d) != 1021.0449f) goto L38;
     */
    /* JADX WARN: Code restructure failed: missing block: B:16:0x008b, code lost:
    
        r17 = r23.collideZ(r19, r17);
     */
    /* JADX WARN: Code restructure failed: missing block: B:17:0x00a1, code lost:
    
        if ((1416.0757f - 10.871828f) == 1405.2039f) goto L85;
     */
    /* JADX WARN: Code restructure failed: missing block: B:18:0x0266, code lost:
    
        r19.offset(0.0d, r15, 0.0d);
     */
    /* JADX WARN: Code restructure failed: missing block: B:20:0x019f, code lost:
    
        if (r22.hasNext() == false) goto L36;
     */
    /* JADX WARN: Code restructure failed: missing block: B:21:0x011c, code lost:
    
        r19.offset(r13, 0.0d, 0.0d);
     */
    /* JADX WARN: Code restructure failed: missing block: B:22:0x01a2, code lost:
    
        r23 = (cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox) r22.next();
     */
    /* JADX WARN: Code restructure failed: missing block: B:23:0x01b9, code lost:
    
        if ((959.723f - 12.371704f) == 947.3513f) goto L25;
     */
    /* JADX WARN: Code restructure failed: missing block: B:24:0x00be, code lost:
    
        r13 = r23.collideX(r19, r13);
     */
    /* JADX WARN: Code restructure failed: missing block: B:25:0x00d5, code lost:
    
        if ((1380.219482421875d - 0.6d) != 1379.6195f) goto L51;
     */
    /* JADX WARN: Code restructure failed: missing block: B:28:0x00fb, code lost:
    
        if (r22.hasNext() == false) goto L84;
     */
    /* JADX WARN: Code restructure failed: missing block: B:29:0x00fe, code lost:
    
        r23 = (cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox) r22.next();
     */
    /* JADX WARN: Code restructure failed: missing block: B:30:0x0116, code lost:
    
        if ((1126.259765625d - 0.4d) == 1125.8597f) goto L86;
     */
    /* JADX WARN: Code restructure failed: missing block: B:34:0x0148, code lost:
    
        r19.offset(0.0d, 0.0d, r17);
     */
    /* JADX WARN: Code restructure failed: missing block: B:35:0x015e, code lost:
    
        if ((730.4888305664062d - 0.9d) != 729.5888f) goto L56;
     */
    /* JADX WARN: Code restructure failed: missing block: B:36:0x012c, code lost:
    
        r15 = r23.collideY(r19, r15);
     */
    /* JADX WARN: Code restructure failed: missing block: B:37:0x0142, code lost:
    
        if ((1129.7697f - 11.013804f) == 1118.7559f) goto L14;
     */
    /* JADX WARN: Code restructure failed: missing block: B:39:0x01c6, code lost:
    
        if (r20.hasNext() == false) goto L6;
     */
    /* JADX WARN: Code restructure failed: missing block: B:3:0x00b8, code lost:
    
        if ((768.781f - 10.338198f) == 758.4428f) goto L3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:41:0x0046, code lost:
    
        return new org.bukkit.util.Vector(r13, r15, r17);
     */
    /* JADX WARN: Code restructure failed: missing block: B:43:0x01c9, code lost:
    
        r21 = (cn.dg32z.lon.utils.nmsutil.Collisions.Axis) r20.next();
     */
    /* JADX WARN: Code restructure failed: missing block: B:44:0x01e1, code lost:
    
        if ((1053.047607421875d - 0.6d) != 1052.4476f) goto L8;
     */
    /* JADX WARN: Code restructure failed: missing block: B:46:0x004c, code lost:
    
        if (r21 != cn.dg32z.lon.utils.nmsutil.Collisions.Axis.X) goto L67;
     */
    /* JADX WARN: Code restructure failed: missing block: B:48:0x021e, code lost:
    
        if (r21 != cn.dg32z.lon.utils.nmsutil.Collisions.Axis.Y) goto L89;
     */
    /* JADX WARN: Code restructure failed: missing block: B:50:0x022d, code lost:
    
        if ((635.57666015625d - 0.6d) == 634.9767f) goto L90;
     */
    /* JADX WARN: Code restructure failed: missing block: B:52:0x00db, code lost:
    
        r22 = r11.iterator();
     */
    /* JADX WARN: Code restructure failed: missing block: B:53:0x00ee, code lost:
    
        if ((680.44965f - 14.389385f) != 666.06024f) goto L51;
     */
    /* JADX WARN: Code restructure failed: missing block: B:58:0x005a, code lost:
    
        if ((1135.1619f - 5.2980595f) == 1129.8638f) goto L61;
     */
    /* JADX WARN: Code restructure failed: missing block: B:59:0x017f, code lost:
    
        r20 = r12.iterator();
     */
    /* JADX WARN: Code restructure failed: missing block: B:5:0x0252, code lost:
    
        if (r21 != cn.dg32z.lon.utils.nmsutil.Collisions.Axis.Z) goto L56;
     */
    /* JADX WARN: Code restructure failed: missing block: B:60:0x0192, code lost:
    
        if ((865.7035f - 11.7474785f) != 853.956f) goto L25;
     */
    /* JADX WARN: Code restructure failed: missing block: B:61:0x0021, code lost:
    
        r15 = r9.getY();
     */
    /* JADX WARN: Code restructure failed: missing block: B:62:0x0033, code lost:
    
        if ((796.070556640625d - 0.7d) == 795.37054f) goto L38;
     */
    /* JADX WARN: Code restructure failed: missing block: B:63:0x0164, code lost:
    
        r17 = r9.getZ();
     */
    /* JADX WARN: Code restructure failed: missing block: B:64:0x0176, code lost:
    
        if ((1299.7548828125d - 0.7d) != 1299.0549f) goto L72;
     */
    /* JADX WARN: Code restructure failed: missing block: B:65:0x0233, code lost:
    
        r19 = r10.copy();
     */
    /* JADX WARN: Code restructure failed: missing block: B:66:0x0244, code lost:
    
        if ((1431.3136f - 6.2918596f) != 1425.0217f) goto L85;
     */
    /* JADX WARN: Code restructure failed: missing block: B:7:0x0260, code lost:
    
        if ((961.13794f - 9.246817f) == 951.8911f) goto L64;
     */
    /* JADX WARN: Code restructure failed: missing block: B:8:0x0200, code lost:
    
        r22 = r11.iterator();
     */
    /* JADX WARN: Code restructure failed: missing block: B:9:0x0213, code lost:
    
        if ((1274.2434f - 8.690824f) != 1265.5526f) goto L61;
     */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:17:0x00a1 -> B:10:0x01e7). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:17:0x00a1 -> B:26:0x00f4). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:21:0x011c -> B:34:0x01bf). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:25:0x00d5 -> B:19:0x0198). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:31:0x015e -> B:53:0x0021). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:33:0x0142 -> B:12:0x0063). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:44:0x005a -> B:10:0x01e7). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:46:0x021e -> B:4:0x024d). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:50:0x00ee -> B:12:0x0063). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:52:0x0192 -> B:34:0x01bf). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:54:0x0033 -> B:32:0x012c). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:56:0x0176 -> B:12:0x0063). Please report as a decompilation issue!!! */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static org.bukkit.util.Vector collideBoundingBoxLegacy(org.bukkit.util.Vector r9, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox r10, java.util.List r11, java.util.List r12) {
        /*
            Method dump skipped, instructions count: 629
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.collideBoundingBoxLegacy(org.bukkit.util.Vector, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox, java.util.List, java.util.List):org.bukkit.util.Vector");
    }

    /* JADX WARN: Code restructure failed: missing block: B:37:0x00b2, code lost:
    
        if ((1114.1766357421875d - 0.6d) == 1113.5767f) goto L31;
     */
    /* JADX WARN: Removed duplicated region for block: B:10:0x00e5  */
    /* JADX WARN: Removed duplicated region for block: B:22:0x0102 A[EDGE_INSN: B:22:0x0102->B:15:0x0102 BREAK  A[LOOP:0: B:2:0x0012->B:17:?], SYNTHETIC] */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private static boolean isSlidingDown(org.bukkit.util.Vector r7, cn.dg32z.lon.player.PlayerData r8, int r9, int r10, int r11) {
        /*
            Method dump skipped, instructions count: 285
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.isSlidingDown(org.bukkit.util.Vector, cn.dg32z.lon.player.PlayerData, int, int, int):boolean");
    }

    /*  JADX ERROR: IndexOutOfBoundsException in pass: SSATransform
        java.lang.IndexOutOfBoundsException: bitIndex < 0: -1
        	at java.base/java.util.BitSet.set(BitSet.java:449)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.fillBasicBlockInfo(LiveVarAnalysis.java:73)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.runAnalysis(LiveVarAnalysis.java:36)
        	at jadx.core.dex.visitors.ssa.SSATransform.process(SSATransform.java:58)
        	at jadx.core.dex.visitors.ssa.SSATransform.visit(SSATransform.java:44)
        */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:100:0x03f8 -> B:11:0x01c4). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:102:0x033c -> B:44:0x0164). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:104:0x0578 -> B:64:0x03bb). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:108:0x011f -> B:56:0x0260). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:110:0x0127 -> B:64:0x03bb). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:112:0x0136 -> B:56:0x0260). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:114:0x0586 -> B:64:0x03bb). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:122:0x03f2 -> B:32:0x02be). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:126:0x024f -> B:159:0x0478). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:134:0x0649 -> B:32:0x02be). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:137:0x04ba -> B:4:0x0472). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:139:0x04c8 -> B:28:0x03fe). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:139:0x04c8 -> B:44:0x0164). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:147:0x068f -> B:11:0x01c4). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:147:0x068f -> B:9:0x06a7). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:149:0x007e -> B:56:0x0260). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:154:0x0454 -> B:24:0x013c). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:158:0x00f5 -> B:48:0x039d). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:27:0x00da -> B:4:0x0472). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:31:0x01be -> B:24:0x013c). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:39:0x04b0 -> B:4:0x0472). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:43:0x02fe -> B:4:0x0472). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:51:0x062a -> B:38:0x049e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:61:0x0397 -> B:28:0x03fe). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:63:0x0609 -> B:48:0x039d). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:66:0x067a -> B:38:0x049e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:72:0x065e -> B:5:0x0084). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:74:0x025a -> B:64:0x03bb). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:89:0x00bf -> B:58:0x0380). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:93:0x0366 -> B:117:0x03d9). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:95:0x04db -> B:9:0x06a7). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:97:0x01fc -> B:30:0x01b1). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:98:0x01ff -> B:32:0x02be). Please report as a decompilation issue!!! */
    public static void forEachCollisionBox(cn.dg32z.lon.player.PlayerData r10, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox r11, java.util.function.Consumer r12) {
        /*
            Method dump skipped, instructions count: 1734
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.forEachCollisionBox(cn.dg32z.lon.player.PlayerData, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox, java.util.function.Consumer):void");
    }

    /* JADX WARN: Code restructure failed: missing block: B:13:0x0046, code lost:
    
        if ((1278.2505f - 9.878998f) == 1268.3715f) goto L72;
     */
    /* JADX WARN: Code restructure failed: missing block: B:14:0x01eb, code lost:
    
        r18 = r18 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:16:0x01fe, code lost:
    
        if (r18 > r15.getBlockZ()) goto L81;
     */
    /* JADX WARN: Code restructure failed: missing block: B:18:0x020c, code lost:
    
        if ((651.1668f - 13.574531f) == 637.5923f) goto L40;
     */
    /* JADX WARN: Code restructure failed: missing block: B:19:0x010f, code lost:
    
        r0 = r10.compensatedWorld.getWrappedBlockStateAt(r16, r17, r18);
     */
    /* JADX WARN: Code restructure failed: missing block: B:20:0x0129, code lost:
    
        if ((788.1572f - 14.563166f) == 773.59406f) goto L67;
     */
    /* JADX WARN: Code restructure failed: missing block: B:21:0x01d3, code lost:
    
        r20 = r0.getType();
     */
    /* JADX WARN: Code restructure failed: missing block: B:22:0x01e5, code lost:
    
        if ((1137.0383f - 5.031304f) == 1132.0071f) goto L3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:24:0x001f, code lost:
    
        if (r20 != cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.type.StateTypes.COBWEB) goto L58;
     */
    /* JADX WARN: Code restructure failed: missing block: B:26:0x002e, code lost:
    
        if ((696.7548828125d - 0.2d) == 696.5549f) goto L71;
     */
    /* JADX WARN: Code restructure failed: missing block: B:27:0x0212, code lost:
    
        return true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:29:0x01b0, code lost:
    
        if (r20 != cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.type.StateTypes.SWEET_BERRY_BUSH) goto L19;
     */
    /* JADX WARN: Code restructure failed: missing block: B:31:0x0091, code lost:
    
        if (r20 != cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.type.StateTypes.POWDER_SNOW) goto L70;
     */
    /* JADX WARN: Code restructure failed: missing block: B:33:0x009f, code lost:
    
        if (r16 != java.lang.Math.floor(r10.x)) goto L70;
     */
    /* JADX WARN: Code restructure failed: missing block: B:35:0x00ad, code lost:
    
        if (r17 != java.lang.Math.floor(r10.y)) goto L70;
     */
    /* JADX WARN: Code restructure failed: missing block: B:37:0x00bb, code lost:
    
        if (r18 != java.lang.Math.floor(r10.z)) goto L70;
     */
    /* JADX WARN: Code restructure failed: missing block: B:39:0x00c8, code lost:
    
        if (r10.getClientVersion().isNewerThanOrEquals(cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion.V_1_17) == false) goto L70;
     */
    /* JADX WARN: Code restructure failed: missing block: B:41:0x00d6, code lost:
    
        if ((1482.102f - 11.948611f) != 1470.1534f) goto L3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:42:?, code lost:
    
        return true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:44:0x01bd, code lost:
    
        if (r10.getClientVersion().isNewerThanOrEquals(cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion.V_1_14) == false) goto L19;
     */
    /* JADX WARN: Code restructure failed: missing block: B:46:0x01cb, code lost:
    
        if ((780.2931f - 8.859932f) == 771.43317f) goto L79;
     */
    /* JADX WARN: Code restructure failed: missing block: B:47:0x0214, code lost:
    
        return true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:48:?, code lost:
    
        return true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:49:?, code lost:
    
        return false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:59:0x0084, code lost:
    
        if ((1441.1526f - 14.824221f) != 1426.3284f) goto L72;
     */
    /* JADX WARN: Code restructure failed: missing block: B:66:0x0109, code lost:
    
        if ((1097.1931f - 11.644427f) != 1085.5487f) goto L19;
     */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:19:0x020c -> B:13:0x0034). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:31:0x0091 -> B:15:0x01eb). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:33:0x009f -> B:15:0x01eb). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:35:0x00ad -> B:15:0x01eb). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:37:0x00bb -> B:15:0x01eb). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:39:0x00c8 -> B:15:0x01eb). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:41:0x00d6 -> B:24:0x001a). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:52:0x0216 -> B:9:0x012f). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:61:0x0084 -> B:16:0x01f7). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:61:0x0084 -> B:9:0x012f). Please report as a decompilation issue!!! */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static boolean checkStuckSpeed(cn.dg32z.lon.player.PlayerData r10, double r11) {
        /*
            Method dump skipped, instructions count: 582
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.checkStuckSpeed(cn.dg32z.lon.player.PlayerData, double):boolean");
    }

    /* JADX WARN: Code restructure failed: missing block: B:16:0x006a, code lost:
    
        if ((1281.1699f - 9.743122f) == 1271.4268f) goto L32;
     */
    /* JADX WARN: Code restructure failed: missing block: B:20:0x00bb, code lost:
    
        if ((1313.85400390625d - 0.6d) != 1313.254f) goto L17;
     */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static java.util.Optional clip(double r22, double r24, double r26, double r28, double r30, double r32, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d r34, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d r35) {
        /*
            Method dump skipped, instructions count: 269
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.clip(double, double, double, double, double, double, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d):java.util.Optional");
    }

    /*  JADX ERROR: IndexOutOfBoundsException in pass: SSATransform
        java.lang.IndexOutOfBoundsException: bitIndex < 0: -1
        	at java.base/java.util.BitSet.set(BitSet.java:449)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.fillBasicBlockInfo(LiveVarAnalysis.java:73)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.runAnalysis(LiveVarAnalysis.java:36)
        	at jadx.core.dex.visitors.ssa.SSATransform.process(SSATransform.java:58)
        	at jadx.core.dex.visitors.ssa.SSATransform.visit(SSATransform.java:44)
        */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    public static boolean trapdoorUsableAsLadder(cn.dg32z.lon.player.PlayerData r8, double r9, double r11, double r13, cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.WrappedBlockState r15) {
        /*
            r0 = 0
            r16 = r0
            goto L67
        L6:
            return r-1
        L7:
            r-1 = r8
            cn.dg32z.lon.utils.latency.CompensatedWorld r-1 = r-1.compensatedWorld
            r0 = r9
            r1 = r11
            r2 = 4607182418800017408(0x3ff0000000000000, double:1.0)
            double r1 = r1 - r2
            r2 = r13
            r-1.getWrappedBlockStateAt(r0, r1, r2)
            r16 = r-1
            r-1 = 4649302198851731456(0x4085a3b780000000, double:692.464599609375)
            r0 = 4591870180066957722(0x3fb999999999999a, double:0.1)
            double r-1 = r-1 - r0
            r0 = 1143805782(0x442d1756, float:692.3646)
            double r0 = (double) r0
            int r-1 = (r-1 > r0 ? 1 : (r-1 == r0 ? 0 : -1))
            if (r-1 != 0) goto L77
            goto L77
        L28:
            r-1 = 0
            return r-1
        L2a:
            r-1 = 0
            r0 = 1140939445(0x44015ab5, float:517.4173)
            r1 = 1096383889(0x41597d91, float:13.593156)
            float r0 = r0 - r1
            r1 = 1140582781(0x43fbe97d, float:503.82413)
            int r0 = (r0 > r1 ? 1 : (r0 == r1 ? 0 : -1))
            if (r0 != 0) goto L6
            goto L6
        L3c:
            r0 = r15
            boolean r0 = r0.isOpen()
            if (r0 == 0) goto L28
            r0 = 4653804912642097152(0x4095a2e940000000, double:1384.727783203125)
            r1 = 4604480259023595110(0x3fe6666666666666, double:0.7)
            double r0 = r0 - r1
            r1 = 1152188644(0x44ad00e4, float:1384.0278)
            double r1 = (double) r1
            int r0 = (r0 > r1 ? 1 : (r0 == r1 ? 0 : -1))
            if (r0 != 0) goto L7
            goto L3c
        L56:
            r0 = r15
            cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.BlockFace r0 = r0.getFacing()
            r1 = r16
            cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.BlockFace r1 = r1.getFacing()
            if (r0 != r1) goto L2a
            r0 = 1
            goto L6
        L67:
            cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.defaulttags.BlockTags r0 = cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.defaulttags.BlockTags.TRAPDOORS
            r1 = r15
            cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.type.StateType r1 = r1.getType()
            boolean r0 = r0.contains(r1)
            if (r0 != 0) goto L94
            r0 = 0
            return r0
        L77:
            r-1 = r16
            r-1.getType()
            cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.type.StateType r0 = cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.type.StateTypes.LADDER
            if (r-1 != r0) goto L28
            r-1 = 4650908884913881088(0x408b58fd40000000, double:875.1236572265625)
            r0 = 4606281698874543309(0x3feccccccccccccd, double:0.9)
            double r-1 = r-1 - r0
            r0 = 1146785360(0x445a8e50, float:874.22363)
            double r0 = (double) r0
            int r-1 = (r-1 > r0 ? 1 : (r-1 == r0 ? 0 : -1))
            if (r-1 == 0) goto L7
            goto L56
        L94:
            r0 = r8
            cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion r0 = r0.getClientVersion()
            cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion r1 = cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion.V_1_8
            boolean r0 = r0.isOlderThanOrEquals(r1)
            if (r0 == 0) goto L3c
            r0 = 0
            return r0
            throw r-1
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.trapdoorUsableAsLadder(cn.dg32z.lon.player.PlayerData, double, double, double, cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.states.WrappedBlockState):boolean");
    }

    /*  JADX ERROR: IndexOutOfBoundsException in pass: SSATransform
        java.lang.IndexOutOfBoundsException: bitIndex < 0: -1
        	at java.base/java.util.BitSet.set(BitSet.java:449)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.fillBasicBlockInfo(LiveVarAnalysis.java:73)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.runAnalysis(LiveVarAnalysis.java:36)
        	at jadx.core.dex.visitors.ssa.SSATransform.process(SSATransform.java:58)
        	at jadx.core.dex.visitors.ssa.SSATransform.visit(SSATransform.java:44)
        */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:18:0x0060 -> B:6:0x00e0). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:22:0x0092 -> B:44:0x01d6). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:28:0x00d7 -> B:6:0x00e0). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:32:0x023e -> B:4:0x0067). Please report as a decompilation issue!!! */
    public static void applyEffectsFromBlocks(cn.dg32z.lon.player.PlayerData r8, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d r9, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d r10) {
        /*
            Method dump skipped, instructions count: 581
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.applyEffectsFromBlocks(cn.dg32z.lon.player.PlayerData, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d):void");
    }

    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    public static Direction clipPoint(double[] dArr, Direction direction, double d, double d2, double d3, double d4, double d5, double d6, double d7, double d8, Direction direction2, double d9, double d10, double d11) {
        double d12;
        do {
            d12 = (d4 - d9) / d;
        } while (679.3362426757812d - 0.2d == 679.1362f);
        double d13 = d10 + (d12 * d2);
        if (1111.687744140625d - 0.8d != 1110.8877f) {
            double d14 = d11 + (d12 * d3);
            if (529.36835f - 7.9913673f == 521.37695f) {
                if (d12 <= 0.0d || d12 >= dArr[0] || d5 - 1.0E-7d >= d13 || d13 >= d6 + 1.0E-7d || d7 - 1.0E-7d >= d14 || d14 >= d8 + 1.0E-7d || 974.1399f - 11.695485f != 962.4444f) {
                    return direction;
                }
            }
            return direction2;
        }
        dArr[0] = d12;
        if (627.01483f - 7.537865f != 619.477f) {
        }
        return direction2;
    }

    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    private static double getNewDeltaY(PlayerData playerData, double d) {
        if (playerData.getClientVersion().isNewerThanOrEquals(ClientVersion.V_1_21_2)) {
            return (d - 0.08d) * 0.9800000190734863d;
        }
        if (1350.5802f - 8.634014f == 1341.9462f) {
        }
        return d;
    }

    /* JADX WARN: Code restructure failed: missing block: B:10:0x0141, code lost:
    
        r31 = java.lang.Math.floor(cn.dg32z.lon.utils.math.MathUtil.clamp(r23 - r27, -r0, r0));
     */
    /* JADX WARN: Code restructure failed: missing block: B:11:0x015f, code lost:
    
        if ((1254.844970703125d - 0.4d) != 1254.445f) goto L3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:12:0x0057, code lost:
    
        r33 = java.lang.Math.floor(cn.dg32z.lon.utils.math.MathUtil.clamp(r25 - r27, -r0, r0));
     */
    /* JADX WARN: Code restructure failed: missing block: B:13:0x0074, code lost:
    
        if ((1442.6472f - 7.373768f) == 1435.2734f) goto L117;
     */
    /* JADX WARN: Code restructure failed: missing block: B:15:0x0093, code lost:
    
        r35 = java.lang.Math.ceil(cn.dg32z.lon.utils.math.MathUtil.clamp(r23 + r27, -r0, r0));
     */
    /* JADX WARN: Code restructure failed: missing block: B:16:0x00b1, code lost:
    
        if ((1238.598388671875d - 0.1d) != 1238.4984f) goto L96;
     */
    /* JADX WARN: Code restructure failed: missing block: B:17:0x036f, code lost:
    
        r37 = java.lang.Math.ceil(cn.dg32z.lon.utils.math.MathUtil.clamp(r25 + r27, -r0, r0));
     */
    /* JADX WARN: Code restructure failed: missing block: B:18:0x038d, code lost:
    
        if ((1077.053466796875d - 0.4d) == 1076.6534f) goto L61;
     */
    /* JADX WARN: Code restructure failed: missing block: B:19:0x00b7, code lost:
    
        r39 = r18.lastX - r31;
     */
    /* JADX WARN: Code restructure failed: missing block: B:20:0x00cb, code lost:
    
        if ((1023.6656f - 8.190098f) != 1015.47546f) goto L6;
     */
    /* JADX WARN: Code restructure failed: missing block: B:21:0x0230, code lost:
    
        r41 = r35 - r18.lastX;
     */
    /* JADX WARN: Code restructure failed: missing block: B:22:0x0245, code lost:
    
        if ((1126.0828857421875d - 0.4d) == 1125.6829f) goto L28;
     */
    /* JADX WARN: Code restructure failed: missing block: B:23:0x010c, code lost:
    
        r43 = java.lang.Math.min(r39, r41);
     */
    /* JADX WARN: Code restructure failed: missing block: B:24:0x0120, code lost:
    
        if ((768.61847f - 5.166731f) == 763.4517f) goto L28;
     */
    /* JADX WARN: Code restructure failed: missing block: B:26:0x024b, code lost:
    
        r53 = r20.iterator();
     */
    /* JADX WARN: Code restructure failed: missing block: B:27:0x025e, code lost:
    
        if ((834.881f - 5.072727f) != 829.8082f) goto L25;
     */
    /* JADX WARN: Code restructure failed: missing block: B:30:0x01fb, code lost:
    
        if (r53.hasNext() == false) goto L115;
     */
    /* JADX WARN: Code restructure failed: missing block: B:31:0x01fe, code lost:
    
        r0 = (cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox) r53.next();
     */
    /* JADX WARN: Code restructure failed: missing block: B:32:0x0215, code lost:
    
        if ((1070.7245f - 7.3577137f) == 1063.3668f) goto L89;
     */
    /* JADX WARN: Code restructure failed: missing block: B:34:0x0351, code lost:
    
        if (r0.isIntersected(r19) == false) goto L121;
     */
    /* JADX WARN: Code restructure failed: missing block: B:36:0x0354, code lost:
    
        return true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:41:0x021c, code lost:
    
        if (r21 == false) goto L109;
     */
    /* JADX WARN: Code restructure failed: missing block: B:43:0x022a, code lost:
    
        if ((1348.8523f - 6.6955757f) == 1342.1567f) goto L61;
     */
    /* JADX WARN: Code restructure failed: missing block: B:44:0x0264, code lost:
    
        r20.add(new cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox(r31, Double.NEGATIVE_INFINITY, r33 - 10.0d, r31, Double.POSITIVE_INFINITY, r37 + 10.0d, false));
     */
    /* JADX WARN: Code restructure failed: missing block: B:45:0x0294, code lost:
    
        if ((1463.5393f - 6.655651f) != 1456.8837f) goto L22;
     */
    /* JADX WARN: Code restructure failed: missing block: B:46:0x00f1, code lost:
    
        r0 = java.lang.Math.min(r45, r47);
     */
    /* JADX WARN: Code restructure failed: missing block: B:47:0x0106, code lost:
    
        if ((1010.1871337890625d - 0.9d) != 1009.2871f) goto L42;
     */
    /* JADX WARN: Code restructure failed: missing block: B:48:0x01a3, code lost:
    
        r0 = java.lang.Math.min(r43, r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:49:0x01b8, code lost:
    
        if ((1269.3260498046875d - 0.6d) != 1268.7261f) goto L76;
     */
    /* JADX WARN: Code restructure failed: missing block: B:51:0x030f, code lost:
    
        if (r0 >= 16.0d) goto L107;
     */
    /* JADX WARN: Code restructure failed: missing block: B:53:0x0319, code lost:
    
        if (r18.lastX <= r31) goto L108;
     */
    /* JADX WARN: Code restructure failed: missing block: B:55:0x0323, code lost:
    
        if (r18.lastX >= r35) goto L110;
     */
    /* JADX WARN: Code restructure failed: missing block: B:57:0x032d, code lost:
    
        if (r18.lastZ <= r33) goto L111;
     */
    /* JADX WARN: Code restructure failed: missing block: B:59:0x0337, code lost:
    
        if (r18.lastZ >= r37) goto L112;
     */
    /* JADX WARN: Code restructure failed: missing block: B:61:0x0345, code lost:
    
        if ((1304.6459f - 8.359904f) != 1296.286f) goto L93;
     */
    /* JADX WARN: Code restructure failed: missing block: B:62:0x0356, code lost:
    
        r25 = r22.getCenterZ();
     */
    /* JADX WARN: Code restructure failed: missing block: B:63:0x0369, code lost:
    
        if ((1136.256591796875d - 0.3d) == 1135.9565f) goto L123;
     */
    /* JADX WARN: Code restructure failed: missing block: B:64:0x029a, code lost:
    
        r27 = r22.getCurrentDiameter() / 2.0d;
     */
    /* JADX WARN: Code restructure failed: missing block: B:65:0x02b1, code lost:
    
        if ((1212.3192138671875d - 0.2d) != 1212.1193f) goto L103;
     */
    /* JADX WARN: Code restructure failed: missing block: B:67:0x01be, code lost:
    
        r20.add(new cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox(r31 - 10.0d, Double.NEGATIVE_INFINITY, r33, r35 + 10.0d, Double.POSITIVE_INFINITY, r33, false));
     */
    /* JADX WARN: Code restructure failed: missing block: B:68:0x01ee, code lost:
    
        if ((1272.3494f - 10.760958f) == 1261.5884f) goto L122;
     */
    /* JADX WARN: Code restructure failed: missing block: B:70:0x0396, code lost:
    
        r20.add(new cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox(r35, Double.NEGATIVE_INFINITY, r33 - 10.0d, r35, Double.POSITIVE_INFINITY, r37 + 10.0d, false));
     */
    /* JADX WARN: Code restructure failed: missing block: B:71:0x03c7, code lost:
    
        if ((1442.56396484375d - 0.9d) != 1441.664f) goto L64;
     */
    /* JADX WARN: Code restructure failed: missing block: B:74:?, code lost:
    
        return false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:76:?, code lost:
    
        return false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:78:?, code lost:
    
        return false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:7:0x019d, code lost:
    
        if ((1295.2523f - 13.431631f) == 1281.8207f) goto L6;
     */
    /* JADX WARN: Code restructure failed: missing block: B:80:?, code lost:
    
        return false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:82:0x00d1, code lost:
    
        return false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:83:0x02b7, code lost:
    
        r47 = r37 - r18.lastZ;
     */
    /* JADX WARN: Code restructure failed: missing block: B:84:0x02cc, code lost:
    
        if ((670.4846801757812d - 0.3d) != 670.1847f) goto L22;
     */
    /* JADX WARN: Code restructure failed: missing block: B:86:?, code lost:
    
        return false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:88:?, code lost:
    
        return false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:8:0x03cd, code lost:
    
        r0 = r22.getAbsoluteMaxSize();
     */
    /* JADX WARN: Code restructure failed: missing block: B:90:0x0166, code lost:
    
        if (r20 != null) goto L73;
     */
    /* JADX WARN: Code restructure failed: missing block: B:91:0x0169, code lost:
    
        r20 = new java.util.ArrayList();
     */
    /* JADX WARN: Code restructure failed: missing block: B:92:0x017d, code lost:
    
        if ((722.7538452148438d - 0.2d) == 722.55383f) goto L120;
     */
    /* JADX WARN: Code restructure failed: missing block: B:93:0x02d2, code lost:
    
        r20.add(new cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox(r31 - 10.0d, Double.NEGATIVE_INFINITY, r37, r35 + 10.0d, Double.POSITIVE_INFINITY, r37, false));
     */
    /* JADX WARN: Code restructure failed: missing block: B:94:0x0303, code lost:
    
        if ((1207.7718505859375d - 0.8d) == 1206.9718f) goto L116;
     */
    /* JADX WARN: Code restructure failed: missing block: B:96:0x007a, code lost:
    
        r23 = r22.getCenterX();
     */
    /* JADX WARN: Code restructure failed: missing block: B:97:0x008d, code lost:
    
        if ((1446.6300048828125d - 0.1d) != 1446.53f) goto L93;
     */
    /* JADX WARN: Code restructure failed: missing block: B:99:0x013b, code lost:
    
        if ((1130.5211181640625d - 0.3d) != 1130.2211f) goto L70;
     */
    /* JADX WARN: Code restructure failed: missing block: B:9:0x03e0, code lost:
    
        if ((977.4483642578125d - 0.7d) != 976.74835f) goto L31;
     */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:24:0x0245 -> B:25:0x010c). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:24:0x0245 -> B:77:0x0126). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:26:0x0120 -> B:27:0x024b). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:40:0x022a -> B:27:0x024b). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:40:0x022a -> B:41:0x0264). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:42:0x0294 -> B:43:0x00f1). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:44:0x0106 -> B:11:0x03cd). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:46:0x01b8 -> B:67:0x02b7). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:66:0x02b1 -> B:11:0x03cd). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:68:0x02cc -> B:11:0x03cd). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:74:0x0303 -> B:61:0x01be). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:76:0x008d -> B:59:0x0356). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:78:0x013b -> B:11:0x03cd). Please report as a decompilation issue!!! */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static boolean addWorldBorder(cn.dg32z.lon.player.PlayerData r18, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox r19, java.util.List r20, boolean r21) {
        /*
            Method dump skipped, instructions count: 1000
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.addWorldBorder(cn.dg32z.lon.player.PlayerData, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox, java.util.List, boolean):boolean");
    }

    /*  JADX ERROR: IndexOutOfBoundsException in pass: SSATransform
        java.lang.IndexOutOfBoundsException: bitIndex < 0: -2
        	at java.base/java.util.BitSet.set(BitSet.java:449)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.fillBasicBlockInfo(LiveVarAnalysis.java:73)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.runAnalysis(LiveVarAnalysis.java:36)
        	at jadx.core.dex.visitors.ssa.SSATransform.process(SSATransform.java:58)
        	at jadx.core.dex.visitors.ssa.SSATransform.visit(SSATransform.java:44)
        */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    public static boolean isAboveGround(cn.dg32z.lon.player.PlayerData r9) {
        /*
            goto L3f
        L3:
            r-1.copy()
            r0 = 0
            r1 = r9
            double r1 = r1.fallDistance
            r2 = r9
            float r2 = r2.getMaxUpStep()
            double r2 = (double) r2
            double r1 = r1 - r2
            r2 = 0
            r-1.offset(r0, r1, r2)
            boolean r-2 = isEmpty(r-2, r-1)
            if (r-2 != 0) goto L2d
            r-2 = 1152700654(0x44b4d0ee, float:1446.529)
            r-1 = 1091916995(0x411554c3, float:9.333194)
            float r-2 = r-2 - r-1
            r-1 = 1152624196(0x44b3a644, float:1437.1958)
            int r-2 = (r-2 > r-1 ? 1 : (r-2 == r-1 ? 0 : -1))
            if (r-2 == 0) goto L77
            goto L77
        L2c:
            return r-3
        L2d:
            r-2 = 0
            r-1 = 1141054791(0x44031d47, float:524.45746)
            r0 = 1090652562(0x41020992, float:8.1273365)
            float r-1 = r-1 - r0
            r0 = 1140921633(0x44011521, float:516.33014)
            int r-1 = (r-1 > r0 ? 1 : (r-1 == r0 ? 0 : -1))
            if (r-1 == 0) goto L2c
            goto L2c
        L3f:
            r0 = r9
            boolean r0 = r0.lastOnGround
            if (r0 != 0) goto L77
            r0 = r9
            cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion r0 = r0.getClientVersion()
            cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion r1 = cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion.V_1_16_2
            boolean r0 = r0.isNewerThanOrEquals(r1)
            if (r0 == 0) goto L2d
            r0 = r9
            double r0 = r0.fallDistance
            r1 = r9
            float r1 = r1.getMaxUpStep()
            double r1 = (double) r1
            int r0 = (r0 > r1 ? 1 : (r0 == r1 ? 0 : -1))
            if (r0 >= 0) goto L2d
            r0 = r9
            r1 = r9
            cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox r1 = r1.boundingBox
            r2 = 4652298694454935552(0x4090490380000000, double:1042.25341796875)
            r3 = 4599075939470750515(0x3fd3333333333333, double:0.3)
            double r2 = r2 - r3
            r3 = 1149386370(0x44823e82, float:1041.9534)
            double r3 = (double) r3
            int r2 = (r2 > r3 ? 1 : (r2 == r3 ? 0 : -1))
            if (r2 == 0) goto L3
            goto L3
        L77:
            r-2 = 1
            goto L2c
            throw r-2
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.isAboveGround(cn.dg32z.lon.player.PlayerData):boolean");
    }

    /* JADX WARN: Code restructure failed: missing block: B:10:0x006c, code lost:
    
        if ((599.25146484375d - 0.1d) != 599.1515f) goto L3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:12:0x01d4, code lost:
    
        if ((974.49316f - 11.093609f) == 963.39954f) goto L27;
     */
    /* JADX WARN: Code restructure failed: missing block: B:22:0x0072, code lost:
    
        r40 = clipPoint(r39, r40, r45, r41, r43, r30, r26, r32, r28, r34, cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.Direction.NORTH, r38.z, r38.x, r38.y);
     */
    /* JADX WARN: Code restructure failed: missing block: B:30:0x0003, code lost:
    
        r40 = clipPoint(r39, r40, r45, r41, r43, r36, r26, r32, r28, r34, cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.Direction.SOUTH, r38.z, r38.x, r38.y);
     */
    /* JADX WARN: Code restructure failed: missing block: B:31:0x0037, code lost:
    
        if ((1423.7769f - 13.1882105f) == 1410.5886f) goto L51;
     */
    /* JADX WARN: Code restructure failed: missing block: B:41:0x0199, code lost:
    
        if ((673.199462890625d - 0.9d) == 672.29944f) goto L6;
     */
    /* JADX WARN: Removed duplicated region for block: B:34:0x00a7  */
    /* JADX WARN: Removed duplicated region for block: B:7:0x0057  */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:16:0x0043 -> B:5:0x009e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:20:0x00ef -> B:5:0x009e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:24:0x0121 -> B:5:0x009e). Please report as a decompilation issue!!! */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private static cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.Direction getDirection(double r26, double r28, double r30, double r32, double r34, double r36, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d r38, double[] r39, cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.Direction r40, double r41, double r43, double r45) {
        /*
            Method dump skipped, instructions count: 476
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.getDirection(double, double, double, double, double, double, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d, double[], cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.Direction, double, double, double):cn.dg32z.libs.com.github.retrooper.packetevents.protocol.world.Direction");
    }

    /* JADX WARN: Code restructure failed: missing block: B:10:0x0044, code lost:
    
        if ((516.7239379882812d - 0.6d) != 516.12396f) goto L39;
     */
    /* JADX WARN: Code restructure failed: missing block: B:14:0x011d, code lost:
    
        r11 = r7.getMinPosition();
     */
    /* JADX WARN: Code restructure failed: missing block: B:15:0x012f, code lost:
    
        if ((1123.7799072265625d - 0.9d) == 1122.8799f) goto L47;
     */
    /* JADX WARN: Code restructure failed: missing block: B:17:0x00bc, code lost:
    
        r0 = r11.subtract(r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:18:0x00cf, code lost:
    
        if ((594.8712f - 5.157899f) != 589.7133f) goto L32;
     */
    /* JADX WARN: Code restructure failed: missing block: B:19:0x00fc, code lost:
    
        addCollisionsAlongTravel(r10, r0, r11, r7);
     */
    /* JADX WARN: Code restructure failed: missing block: B:20:0x0111, code lost:
    
        if ((565.8562f - 11.460589f) == 554.3956f) goto L17;
     */
    /* JADX WARN: Code restructure failed: missing block: B:21:0x0082, code lost:
    
        r13 = r0.iterator();
     */
    /* JADX WARN: Code restructure failed: missing block: B:22:0x0097, code lost:
    
        if ((1329.5380859375d - 0.9d) != 1328.6381f) goto L27;
     */
    /* JADX WARN: Code restructure failed: missing block: B:26:0x00f6, code lost:
    
        if ((626.2519f - 7.9573965f) != 618.2945f) goto L24;
     */
    /* JADX WARN: Code restructure failed: missing block: B:27:0x00a0, code lost:
    
        r10.add(r14);
     */
    /* JADX WARN: Code restructure failed: missing block: B:28:0x00b6, code lost:
    
        if ((1046.365478515625d - 0.2d) == 1046.1655f) goto L37;
     */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:21:0x00f6 -> B:12:0x00bc). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:23:0x00b6 -> B:18:0x00d5). Please report as a decompilation issue!!! */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static java.lang.Iterable boxTraverseBlocks(cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d r5, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d r6, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox r7) {
        /*
            Method dump skipped, instructions count: 311
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.boxTraverseBlocks(cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d, cn.dg32z.libs.com.github.retrooper.packetevents.util.Vector3d, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox):java.lang.Iterable");
    }

    /*  JADX ERROR: IndexOutOfBoundsException in pass: SSATransform
        java.lang.IndexOutOfBoundsException: bitIndex < 0: -1
        	at java.base/java.util.BitSet.get(BitSet.java:628)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.fillBasicBlockInfo(LiveVarAnalysis.java:65)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.runAnalysis(LiveVarAnalysis.java:36)
        	at jadx.core.dex.visitors.ssa.SSATransform.process(SSATransform.java:58)
        	at jadx.core.dex.visitors.ssa.SSATransform.visit(SSATransform.java:44)
        */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    private static double getOldDeltaY(cn.dg32z.lon.player.PlayerData r7, double r8) {
        /*
            goto L4
        L3:
            return r-1
        L4:
            r0 = r7
            cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion r0 = r0.getClientVersion()
            cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion r1 = cn.dg32z.libs.com.github.retrooper.packetevents.protocol.player.ClientVersion.V_1_21_2
            boolean r0 = r0.isNewerThanOrEquals(r1)
            if (r0 == 0) goto L1d
            r0 = r8
            r1 = 4607002274986721280(0x3fef5c2900000000, double:0.9800000190734863)
            double r0 = r0 / r1
            r1 = 4590429028186199163(0x3fb47ae147ae147b, double:0.08)
            double r0 = r0 + r1
            goto L3
        L1d:
            r0 = r8
            r1 = 4650448696347983872(0x4089b67340000000, double:822.8062744140625)
            r2 = 4599075939470750515(0x3fd3333333333333, double:0.3)
            double r1 = r1 - r2
            r2 = 1145938023(0x444da067, float:822.5063)
            double r2 = (double) r2
            int r1 = (r1 > r2 ? 1 : (r1 == r2 ? 0 : -1))
            if (r1 != 0) goto L3
            goto L3
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.getOldDeltaY(cn.dg32z.lon.player.PlayerData, double):double");
    }

    /* JADX WARN: Code restructure failed: missing block: B:12:0x0119, code lost:
    
        if (r23 != (-r19)) goto L6;
     */
    /* JADX WARN: Code restructure failed: missing block: B:13:0x0040, code lost:
    
        return true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:16:0x0122, code lost:
    
        if (r25 != (-r19)) goto L6;
     */
    /* JADX WARN: Code restructure failed: missing block: B:18:0x012b, code lost:
    
        if (r21 != (-r19)) goto L6;
     */
    /* JADX WARN: Code restructure failed: missing block: B:20:0x0134, code lost:
    
        if (r27 == (-r19)) goto L23;
     */
    /* JADX WARN: Code restructure failed: missing block: B:22:0x00ea, code lost:
    
        if ((604.53662109375d - 0.1d) != 604.43665f) goto L48;
     */
    /* JADX WARN: Code restructure failed: missing block: B:23:?, code lost:
    
        return false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:25:0x0142, code lost:
    
        if ((855.8424f - 9.98068f) != 845.86176f) goto L7;
     */
    /* JADX WARN: Code restructure failed: missing block: B:27:0x0056, code lost:
    
        if ((904.1068115234375d - 0.9d) != 903.2068f) goto L29;
     */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:22:0x0056 -> B:6:0x0113). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:24:0x0091 -> B:21:0x0044). Please report as a decompilation issue!!! */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static boolean slowCouldPointThreeHitGround(cn.dg32z.lon.player.PlayerData r11, double r12, double r14, double r16) {
        /*
            Method dump skipped, instructions count: 353
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.slowCouldPointThreeHitGround(cn.dg32z.lon.player.PlayerData, double, double, double):boolean");
    }

    /*  JADX ERROR: IndexOutOfBoundsException in pass: SSATransform
        java.lang.IndexOutOfBoundsException: bitIndex < 0: -1
        	at java.base/java.util.BitSet.set(BitSet.java:449)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.fillBasicBlockInfo(LiveVarAnalysis.java:73)
        	at jadx.core.dex.visitors.ssa.LiveVarAnalysis.runAnalysis(LiveVarAnalysis.java:36)
        	at jadx.core.dex.visitors.ssa.SSATransform.process(SSATransform.java:58)
        	at jadx.core.dex.visitors.ssa.SSATransform.visit(SSATransform.java:44)
        */
    /* JADX WARN: Unreachable blocks removed: 1, instructions: 1 */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:103:0x0098 -> B:10:0x0425). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:105:0x00a2 -> B:10:0x0425). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:107:0x00b1 -> B:116:0x04b0). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:109:0x0214 -> B:110:0x032a). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:115:0x02d4 -> B:25:0x030e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:115:0x02d4 -> B:89:0x01d3). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:127:0x047d -> B:83:0x02f2). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:24:0x00fc -> B:12:0x037e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:26:0x0324 -> B:12:0x037e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:34:0x027c -> B:17:0x01a2). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:40:0x0152 -> B:29:0x0247). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:44:0x0372 -> B:25:0x030e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:60:0x0241 -> B:111:0x044f). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:65:0x0110 -> B:21:0x0291). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:67:0x0168 -> B:39:0x0141). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:67:0x0168 -> B:68:0x01e6). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:73:0x02b9 -> B:12:0x037e). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:73:0x02b9 -> B:17:0x01a2). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:82:0x0491 -> B:14:0x00b7). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:84:0x0300 -> B:4:0x018a). Please report as a decompilation issue!!! */
    /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:90:0x01e0 -> B:81:0x0483). Please report as a decompilation issue!!! */
    public static boolean hasMaterial(cn.dg32z.lon.player.PlayerData r13, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox r14, java.util.function.Predicate r15) {
        /*
            Method dump skipped, instructions count: 1331
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: cn.dg32z.lon.utils.nmsutil.Collisions.hasMaterial(cn.dg32z.lon.player.PlayerData, cn.dg32z.lon.utils.collisions.datatypes.SimpleCollisionBox, java.util.function.Predicate):boolean");
    }
}
